"""
Python module generated from Java source file com.google.common.util.concurrent.WrappingExecutorService

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import ImmutableList
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util.concurrent import Callable
from java.util.concurrent import ExecutionException
from java.util.concurrent import ExecutorService
from java.util.concurrent import Executors
from java.util.concurrent import Future
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class WrappingExecutorService(ExecutorService):
    """
    An abstract `ExecutorService` that allows subclasses to .wrapTask(Callable)
    wrap tasks before they are submitted to the underlying executor.
    
    Note that task wrapping may occur even if the task is never executed.
    
    For delegation without task-wrapping, see ForwardingExecutorService.

    Author(s)
    - Chris Nokleberg
    """

    def execute(self, command: "Runnable") -> None:
        ...


    def submit(self, task: "Callable"["T"]) -> "Future"["T"]:
        ...


    def submit(self, task: "Runnable") -> "Future"[Any]:
        ...


    def submit(self, task: "Runnable", result: "T") -> "Future"["T"]:
        ...


    def invokeAll(self, tasks: Iterable["Callable"["T"]]) -> list["Future"["T"]]:
        ...


    def invokeAll(self, tasks: Iterable["Callable"["T"]], timeout: int, unit: "TimeUnit") -> list["Future"["T"]]:
        ...


    def invokeAny(self, tasks: Iterable["Callable"["T"]]) -> "T":
        ...


    def invokeAny(self, tasks: Iterable["Callable"["T"]], timeout: int, unit: "TimeUnit") -> "T":
        ...


    def shutdown(self) -> None:
        ...


    def shutdownNow(self) -> list["Runnable"]:
        ...


    def isShutdown(self) -> bool:
        ...


    def isTerminated(self) -> bool:
        ...


    def awaitTermination(self, timeout: int, unit: "TimeUnit") -> bool:
        ...



"""
Python module generated from Java source file com.google.gson.internal.LinkedTreeMap

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.gson.internal import *
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectStreamException
from java.io import Serializable
from java.util import AbstractSet
from java.util import Comparator
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class LinkedTreeMap(AbstractMap, Serializable):
    """
    A map of comparable keys to values. Unlike `TreeMap`, this class uses insertion order for
    iteration order. Comparison order is only used as an optimization for efficient insertion and
    removal.
    
    This implementation was derived from Android 4.1's TreeMap class.
    """

    def __init__(self):
        """
        Create a natural order, empty tree map whose keys must be mutually comparable and non-null, and
        whose values can be `null`.
        """
        ...


    def __init__(self, allowNullValues: bool):
        """
        Create a natural order, empty tree map whose keys must be mutually comparable and non-null.

        Arguments
        - allowNullValues: whether `null` is allowed as entry value
        """
        ...


    def __init__(self, comparator: "Comparator"["K"], allowNullValues: bool):
        ...


    def size(self) -> int:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def clear(self) -> None:
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...


    def keySet(self) -> set["K"]:
        ...



"""
Python module generated from Java source file com.google.common.io.MultiReader

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.io import *
from java.io import IOException
from java.io import Reader
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MultiReader(Reader):
    """
    A Reader that concatenates multiple readers.

    Author(s)
    - Bin Zhu

    Since
    - 1.0
    """

    def read(self, cbuf: list[str], off: int, len: int) -> int:
        ...


    def skip(self, n: int) -> int:
        ...


    def ready(self) -> bool:
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.block.DoubleChest

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit import World
from org.bukkit.block import *
from org.bukkit.inventory import DoubleChestInventory
from org.bukkit.inventory import Inventory
from org.bukkit.inventory import InventoryHolder
from typing import Any, Callable, Iterable, Tuple


class DoubleChest(InventoryHolder):
    """
    Represents a double chest.
    """

    def __init__(self, chest: "DoubleChestInventory"):
        ...


    def getInventory(self) -> "Inventory":
        ...


    def getLeftSide(self) -> "InventoryHolder":
        ...


    def getRightSide(self) -> "InventoryHolder":
        ...


    def getLocation(self) -> "Location":
        ...


    def getWorld(self) -> "World":
        ...


    def getX(self) -> float:
        ...


    def getY(self) -> float:
        ...


    def getZ(self) -> float:
        ...



from .PlayerRecipeDiscoverEvent import PlayerRecipeDiscoverEvent
from .PlayerPreLoginEvent import PlayerPreLoginEvent
from .PlayerSwapHandItemsEvent import PlayerSwapHandItemsEvent
from .PlayerQuitEvent import PlayerQuitEvent
from .PlayerMoveEvent import PlayerMoveEvent
from .PlayerExpCooldownChangeEvent import PlayerExpCooldownChangeEvent
from .PlayerStatisticIncrementEvent import PlayerStatisticIncrementEvent
from .PlayerToggleSprintEvent import PlayerToggleSprintEvent
from .AsyncPlayerChatPreviewEvent import AsyncPlayerChatPreviewEvent
from .PlayerResourcePackStatusEvent import PlayerResourcePackStatusEvent
from .PlayerBedLeaveEvent import PlayerBedLeaveEvent
from .PlayerPortalEvent import PlayerPortalEvent
from .PlayerChannelEvent import PlayerChannelEvent
from .PlayerLoginEvent import PlayerLoginEvent
from .PlayerLinksSendEvent import PlayerLinksSendEvent
from .PlayerLevelChangeEvent import PlayerLevelChangeEvent
from .PlayerArmorStandManipulateEvent import PlayerArmorStandManipulateEvent
from .PlayerAnimationType import PlayerAnimationType
from .PlayerToggleFlightEvent import PlayerToggleFlightEvent
from .PlayerLocaleChangeEvent import PlayerLocaleChangeEvent
from .PlayerBucketFishEvent import PlayerBucketFishEvent
from .PlayerHarvestBlockEvent import PlayerHarvestBlockEvent
from .PlayerJoinEvent import PlayerJoinEvent
from .PlayerInteractEvent import PlayerInteractEvent
from .PlayerTakeLecternBookEvent import PlayerTakeLecternBookEvent
from .PlayerGameModeChangeEvent import PlayerGameModeChangeEvent
from .PlayerRiptideEvent import PlayerRiptideEvent
from .PlayerRecipeBookClickEvent import PlayerRecipeBookClickEvent
from .PlayerChangedMainHandEvent import PlayerChangedMainHandEvent
from .PlayerVelocityEvent import PlayerVelocityEvent
from .PlayerUnregisterChannelEvent import PlayerUnregisterChannelEvent
from .PlayerRespawnEvent import PlayerRespawnEvent
from .PlayerDropItemEvent import PlayerDropItemEvent
from .PlayerFishEvent import PlayerFishEvent
from .PlayerEggThrowEvent import PlayerEggThrowEvent
from .PlayerBucketEvent import PlayerBucketEvent
from .PlayerChangedWorldEvent import PlayerChangedWorldEvent
from .PlayerPickupItemEvent import PlayerPickupItemEvent
from .PlayerAdvancementDoneEvent import PlayerAdvancementDoneEvent
from .PlayerUnleashEntityEvent import PlayerUnleashEntityEvent
from .PlayerShearEntityEvent import PlayerShearEntityEvent
from .PlayerHideEntityEvent import PlayerHideEntityEvent
from .PlayerSignOpenEvent import PlayerSignOpenEvent
from .PlayerEvent import PlayerEvent
from .PlayerShowEntityEvent import PlayerShowEntityEvent
from .PlayerPickupArrowEvent import PlayerPickupArrowEvent
from .PlayerInputEvent import PlayerInputEvent
from .PlayerRecipeBookSettingsChangeEvent import PlayerRecipeBookSettingsChangeEvent
from .PlayerSpawnChangeEvent import PlayerSpawnChangeEvent
from .PlayerBedEnterEvent import PlayerBedEnterEvent
from .PlayerBucketEntityEvent import PlayerBucketEntityEvent
from .PlayerItemConsumeEvent import PlayerItemConsumeEvent
from .PlayerAnimationEvent import PlayerAnimationEvent
from .PlayerRegisterChannelEvent import PlayerRegisterChannelEvent
from .PlayerExpChangeEvent import PlayerExpChangeEvent
from .PlayerInteractAtEntityEvent import PlayerInteractAtEntityEvent
from .PlayerChatEvent import PlayerChatEvent
from .PlayerItemHeldEvent import PlayerItemHeldEvent
from .PlayerItemMendEvent import PlayerItemMendEvent
from .PlayerKickEvent import PlayerKickEvent
from .PlayerEditBookEvent import PlayerEditBookEvent
from .PlayerItemBreakEvent import PlayerItemBreakEvent
from .AsyncPlayerPreLoginEvent import AsyncPlayerPreLoginEvent
from .PlayerToggleSneakEvent import PlayerToggleSneakEvent
from .PlayerCommandSendEvent import PlayerCommandSendEvent
from .PlayerBucketFillEvent import PlayerBucketFillEvent
from .PlayerTeleportEvent import PlayerTeleportEvent
from .PlayerChatTabCompleteEvent import PlayerChatTabCompleteEvent
from .PlayerCommandPreprocessEvent import PlayerCommandPreprocessEvent
from .PlayerItemDamageEvent import PlayerItemDamageEvent
from .PlayerInteractEntityEvent import PlayerInteractEntityEvent
from .AsyncPlayerChatEvent import AsyncPlayerChatEvent
from .PlayerBucketEmptyEvent import PlayerBucketEmptyEvent


"""
Python module generated from Java source file com.google.common.graph.SuccessorsFunction

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.graph import *
from com.google.errorprone.annotations import DoNotMock
from typing import Any, Callable, Iterable, Tuple


class SuccessorsFunction:
    """
    A functional interface for <a
    href="https://en.wikipedia.org/wiki/Graph_(discrete_mathematics)">graph</a>-structured data.
    
    This interface is meant to be used as the type of a parameter to graph algorithms (such as
    breadth first traversal) that only need a way of accessing the successors of a node in a graph.
    
    <h3>Usage</h3>
    
    Given an algorithm, for example:
    
    ````public <N> someGraphAlgorithm(N startNode, SuccessorsFunction<N> successorsFunction);````
    
    you will invoke it depending on the graph representation you're using.
    
    If you have an instance of one of the primary `common.graph` types (Graph,
    ValueGraph, and Network):
    
    ````someGraphAlgorithm(startNode, graph);````
    
    This works because those types each implement `SuccessorsFunction`. It will also work with
    any other implementation of this interface.
    
    If you have your own graph implementation based around a custom node type `MyNode`,
    which has a method `getChildren()` that retrieves its successors in a graph:
    
    ````someGraphAlgorithm(startNode, MyNode::getChildren);````
    
    If you have some other mechanism for returning the successors of a node, or one that doesn't
    return an `Iterable<? extends N>`, then you can use a lambda to perform a more general
    transformation:
    
    ````someGraphAlgorithm(startNode, node -> ImmutableList.of(node.leftChild(), node.rightChild()));````
    
    Graph algorithms that need additional capabilities (accessing both predecessors and
    successors, iterating over the edges, etc.) should declare their input to be of a type that
    provides those capabilities, such as Graph, ValueGraph, or Network.
    
    <h3>Additional documentation</h3>
    
    See the Guava User Guide for the `common.graph` package (<a
    href="https://github.com/google/guava/wiki/GraphsExplained">"Graphs Explained"</a>) for
    additional documentation, including <a
    href="https://github.com/google/guava/wiki/GraphsExplained#notes-for-implementors">notes for
    implementors</a>
    
    Type `<N>`: Node parameter type

    Author(s)
    - Jens Nyman

    Since
    - 23.0
    """

    def successors(self, node: "N") -> Iterable["N"]:
        """
        Returns all nodes in this graph adjacent to `node` which can be reached by traversing
        `node`'s outgoing edges in the direction (if any) of the edge.
        
        This is *not* the same as "all nodes reachable from `node` by following outgoing
        edges". For that functionality, see Graphs.reachableNodes(Graph, Object).
        
        Some algorithms that operate on a `SuccessorsFunction` may produce undesired results
        if the returned Iterable contains duplicate elements. Implementations of such
        algorithms should document their behavior in the presence of duplicates.
        
        The elements of the returned `Iterable` must each be:
        
        
          - Non-null
          - Usable as `Map` keys (see the Guava User Guide's section on <a
              href="https://github.com/google/guava/wiki/GraphsExplained#graph-elements-nodes-and-edges">
              graph elements</a> for details)

        Raises
        - IllegalArgumentException: if `node` is not an element of this graph
        """
        ...



"""
Python module generated from Java source file java.util.EnumSet

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from jdk.internal.access import SharedSecrets
from typing import Any, Callable, Iterable, Tuple


class EnumSet(AbstractSet, Cloneable, Serializable):
    """
    A specialized Set implementation for use with enum types.  All of
    the elements in an enum set must come from a single enum type that is
    specified, explicitly or implicitly, when the set is created.  Enum sets
    are represented internally as bit vectors.  This representation is
    extremely compact and efficient. The space and time performance of this
    class should be good enough to allow its use as a high-quality, typesafe
    alternative to traditional `int`-based "bit flags."  Even bulk
    operations (such as `containsAll` and `retainAll`) should
    run very quickly if their argument is also an enum set.
    
    The iterator returned by the `iterator` method traverses the
    elements in their *natural order* (the order in which the enum
    constants are declared).  The returned iterator is *weakly
    consistent*: it will never throw ConcurrentModificationException
    and it may or may not show the effects of any modifications to the set that
    occur while the iteration is in progress.
    
    Null elements are not permitted.  Attempts to insert a null element
    will throw NullPointerException.  Attempts to test for the
    presence of a null element or to remove one will, however, function
    properly.
    
    <P>Like most collection implementations, `EnumSet` is not
    synchronized.  If multiple threads access an enum set concurrently, and at
    least one of the threads modifies the set, it should be synchronized
    externally.  This is typically accomplished by synchronizing on some
    object that naturally encapsulates the enum set.  If no such object exists,
    the set should be "wrapped" using the Collections.synchronizedSet
    method.  This is best done at creation time, to prevent accidental
    unsynchronized access:
    
    ```
    Set&lt;MyEnum&gt; s = Collections.synchronizedSet(EnumSet.noneOf(MyEnum.class));
    ```
    
    Implementation note: All basic operations execute in constant time.
    They are likely (though not guaranteed) to be much faster than their
    HashSet counterparts.  Even bulk operations execute in
    constant time if their argument is also an enum set.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.

    Author(s)
    - Josh Bloch

    See
    - EnumMap

    Since
    - 1.5
    """

    @staticmethod
    def noneOf(elementType: type["E"]) -> "EnumSet"["E"]:
        """
        Creates an empty enum set with the specified element type.
        
        Type `<E>`: The class of the elements in the set

        Arguments
        - elementType: the class object of the element type for this enum
            set

        Returns
        - An empty enum set of the specified type.

        Raises
        - NullPointerException: if `elementType` is null
        """
        ...


    @staticmethod
    def allOf(elementType: type["E"]) -> "EnumSet"["E"]:
        """
        Creates an enum set containing all of the elements in the specified
        element type.
        
        Type `<E>`: The class of the elements in the set

        Arguments
        - elementType: the class object of the element type for this enum
            set

        Returns
        - An enum set containing all the elements in the specified type.

        Raises
        - NullPointerException: if `elementType` is null
        """
        ...


    @staticmethod
    def copyOf(s: "EnumSet"["E"]) -> "EnumSet"["E"]:
        """
        Creates an enum set with the same element type as the specified enum
        set, initially containing the same elements (if any).
        
        Type `<E>`: The class of the elements in the set

        Arguments
        - s: the enum set from which to initialize this enum set

        Returns
        - A copy of the specified enum set.

        Raises
        - NullPointerException: if `s` is null
        """
        ...


    @staticmethod
    def copyOf(c: Iterable["E"]) -> "EnumSet"["E"]:
        """
        Creates an enum set initialized from the specified collection.  If
        the specified collection is an `EnumSet` instance, this static
        factory method behaves identically to .copyOf(EnumSet).
        Otherwise, the specified collection must contain at least one element
        (in order to determine the new enum set's element type).
        
        Type `<E>`: The class of the elements in the collection

        Arguments
        - c: the collection from which to initialize this enum set

        Returns
        - An enum set initialized from the given collection.

        Raises
        - IllegalArgumentException: if `c` is not an
            `EnumSet` instance and contains no elements
        - NullPointerException: if `c` is null
        """
        ...


    @staticmethod
    def complementOf(s: "EnumSet"["E"]) -> "EnumSet"["E"]:
        """
        Creates an enum set with the same element type as the specified enum
        set, initially containing all the elements of this type that are
        *not* contained in the specified set.
        
        Type `<E>`: The class of the elements in the enum set

        Arguments
        - s: the enum set from whose complement to initialize this enum set

        Returns
        - The complement of the specified set in this set

        Raises
        - NullPointerException: if `s` is null
        """
        ...


    @staticmethod
    def of(e: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified element.
        
        Overloadings of this method exist to initialize an enum set with
        one through five elements.  A sixth overloading is provided that
        uses the varargs feature.  This overloading may be used to create
        an enum set initially containing an arbitrary number of elements, but
        is likely to run slower than the overloadings that do not use varargs.
        
        Type `<E>`: The class of the specified element and of the set

        Arguments
        - e: the element that this set is to contain initially

        Returns
        - an enum set initially containing the specified element

        Raises
        - NullPointerException: if `e` is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified elements.
        
        Overloadings of this method exist to initialize an enum set with
        one through five elements.  A sixth overloading is provided that
        uses the varargs feature.  This overloading may be used to create
        an enum set initially containing an arbitrary number of elements, but
        is likely to run slower than the overloadings that do not use varargs.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - e1: an element that this set is to contain initially
        - e2: another element that this set is to contain initially

        Returns
        - an enum set initially containing the specified elements

        Raises
        - NullPointerException: if any parameters are null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified elements.
        
        Overloadings of this method exist to initialize an enum set with
        one through five elements.  A sixth overloading is provided that
        uses the varargs feature.  This overloading may be used to create
        an enum set initially containing an arbitrary number of elements, but
        is likely to run slower than the overloadings that do not use varargs.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - e1: an element that this set is to contain initially
        - e2: another element that this set is to contain initially
        - e3: another element that this set is to contain initially

        Returns
        - an enum set initially containing the specified elements

        Raises
        - NullPointerException: if any parameters are null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified elements.
        
        Overloadings of this method exist to initialize an enum set with
        one through five elements.  A sixth overloading is provided that
        uses the varargs feature.  This overloading may be used to create
        an enum set initially containing an arbitrary number of elements, but
        is likely to run slower than the overloadings that do not use varargs.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - e1: an element that this set is to contain initially
        - e2: another element that this set is to contain initially
        - e3: another element that this set is to contain initially
        - e4: another element that this set is to contain initially

        Returns
        - an enum set initially containing the specified elements

        Raises
        - NullPointerException: if any parameters are null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified elements.
        
        Overloadings of this method exist to initialize an enum set with
        one through five elements.  A sixth overloading is provided that
        uses the varargs feature.  This overloading may be used to create
        an enum set initially containing an arbitrary number of elements, but
        is likely to run slower than the overloadings that do not use varargs.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - e1: an element that this set is to contain initially
        - e2: another element that this set is to contain initially
        - e3: another element that this set is to contain initially
        - e4: another element that this set is to contain initially
        - e5: another element that this set is to contain initially

        Returns
        - an enum set initially containing the specified elements

        Raises
        - NullPointerException: if any parameters are null
        """
        ...


    @staticmethod
    def of(first: "E", *rest: Tuple["E", ...]) -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing the specified elements.
        This factory, whose parameter list uses the varargs feature, may
        be used to create an enum set initially containing an arbitrary
        number of elements, but it is likely to run slower than the overloadings
        that do not use varargs.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - first: an element that the set is to contain initially
        - rest: the remaining elements the set is to contain initially

        Returns
        - an enum set initially containing the specified elements

        Raises
        - NullPointerException: if any of the specified elements are null,
            or if `rest` is null
        """
        ...


    @staticmethod
    def range(from: "E", to: "E") -> "EnumSet"["E"]:
        """
        Creates an enum set initially containing all of the elements in the
        range defined by the two specified endpoints.  The returned set will
        contain the endpoints themselves, which may be identical but must not
        be out of order.
        
        Type `<E>`: The class of the parameter elements and of the set

        Arguments
        - from: the first element in the range
        - to: the last element in the range

        Returns
        - an enum set initially containing all of the elements in the
                range defined by the two specified endpoints

        Raises
        - NullPointerException: if `from` or `to` are null
        - IllegalArgumentException: if `from.compareTo(to) > 0`
        """
        ...


    def clone(self) -> "EnumSet"["E"]:
        """
        Returns a copy of this set.

        Returns
        - a copy of this set
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.BaseComponent

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from net.md_5.bungee.api.chat.ComponentBuilder import FormatRetention
from typing import Any, Callable, Iterable, Tuple


class BaseComponent:

    def __init__(self):
        """
        Default constructor.

        Deprecated
        - for use by internal classes only, will be removed.
        """
        ...


    def copyFormatting(self, component: "BaseComponent") -> None:
        """
        Copies the events and formatting of a BaseComponent. Already set
        formatting will be replaced.

        Arguments
        - component: the component to copy from
        """
        ...


    def copyFormatting(self, component: "BaseComponent", replace: bool) -> None:
        """
        Copies the events and formatting of a BaseComponent.

        Arguments
        - component: the component to copy from
        - replace: if already set formatting should be replaced by the new
        component
        """
        ...


    def copyFormatting(self, component: "BaseComponent", retention: "FormatRetention", replace: bool) -> None:
        """
        Copies the specified formatting of a BaseComponent.

        Arguments
        - component: the component to copy from
        - retention: the formatting to copy
        - replace: if already set formatting should be replaced by the new
        component
        """
        ...


    def retain(self, retention: "FormatRetention") -> None:
        """
        Retains only the specified formatting.

        Arguments
        - retention: the formatting to retain
        """
        ...


    def duplicate(self) -> "BaseComponent":
        """
        Clones the BaseComponent and returns the clone.

        Returns
        - The duplicate of this BaseComponent
        """
        ...


    def duplicateWithoutFormatting(self) -> "BaseComponent":
        """
        Clones the BaseComponent without formatting and returns the clone.

        Returns
        - The duplicate of this BaseComponent

        Deprecated
        - API use discouraged, use traditional duplicate
        """
        ...


    @staticmethod
    def toLegacyText(*components: Tuple["BaseComponent", ...]) -> str:
        """
        Converts the components to a string that uses the old formatting codes
        (net.md_5.bungee.api.ChatColor.COLOR_CHAR

        Arguments
        - components: the components to convert

        Returns
        - the string in the old format
        """
        ...


    @staticmethod
    def toPlainText(*components: Tuple["BaseComponent", ...]) -> str:
        """
        Converts the components into a string without any formatting

        Arguments
        - components: the components to convert

        Returns
        - the string as plain text
        """
        ...


    def setStyle(self, style: "ComponentStyle") -> None:
        """
        Set the ComponentStyle for this component.
        
        Unlike .applyStyle(ComponentStyle), this method will overwrite
        all style values on this component.

        Arguments
        - style: the style to set, or null to set all style values to default
        """
        ...


    def setColor(self, color: "ChatColor") -> None:
        """
        Set this component's color.

        Arguments
        - color: the component color, or null to use the default
        """
        ...


    def getColor(self) -> "ChatColor":
        """
        Returns the color of this component. This uses the parent's color if this
        component doesn't have one. net.md_5.bungee.api.ChatColor.WHITE
        is returned if no color is found.

        Returns
        - the color of this component
        """
        ...


    def getColorRaw(self) -> "ChatColor":
        """
        Returns the color of this component without checking the parents color.
        May return null

        Returns
        - the color of this component
        """
        ...


    def setFont(self, font: str) -> None:
        """
        Set this component's font.

        Arguments
        - font: the font to set, or null to use the default
        """
        ...


    def getFont(self) -> str:
        """
        Returns the font of this component. This uses the parent's font if this
        component doesn't have one.

        Returns
        - the font of this component, or null if default font
        """
        ...


    def getFontRaw(self) -> str:
        """
        Returns the font of this component without checking the parents font. May
        return null

        Returns
        - the font of this component
        """
        ...


    def setBold(self, bold: "Boolean") -> None:
        """
        Set whether or not this component is bold.

        Arguments
        - bold: the new bold state, or null to use the default
        """
        ...


    def isBold(self) -> bool:
        """
        Returns whether this component is bold. This uses the parent's setting if
        this component hasn't been set. False is returned if none of the parent
        chain has been set.

        Returns
        - whether the component is bold
        """
        ...


    def isBoldRaw(self) -> "Boolean":
        """
        Returns whether this component is bold without checking the parents
        setting. May return null

        Returns
        - whether the component is bold
        """
        ...


    def setItalic(self, italic: "Boolean") -> None:
        """
        Set whether or not this component is italic.

        Arguments
        - italic: the new italic state, or null to use the default
        """
        ...


    def isItalic(self) -> bool:
        """
        Returns whether this component is italic. This uses the parent's setting
        if this component hasn't been set. False is returned if none of the
        parent chain has been set.

        Returns
        - whether the component is italic
        """
        ...


    def isItalicRaw(self) -> "Boolean":
        """
        Returns whether this component is italic without checking the parents
        setting. May return null

        Returns
        - whether the component is italic
        """
        ...


    def setUnderlined(self, underlined: "Boolean") -> None:
        """
        Set whether or not this component is underlined.

        Arguments
        - underlined: the new underlined state, or null to use the default
        """
        ...


    def isUnderlined(self) -> bool:
        """
        Returns whether this component is underlined. This uses the parent's
        setting if this component hasn't been set. False is returned if none of
        the parent chain has been set.

        Returns
        - whether the component is underlined
        """
        ...


    def isUnderlinedRaw(self) -> "Boolean":
        """
        Returns whether this component is underlined without checking the parents
        setting. May return null

        Returns
        - whether the component is underlined
        """
        ...


    def setStrikethrough(self, strikethrough: "Boolean") -> None:
        """
        Set whether or not this component is strikethrough.

        Arguments
        - strikethrough: the new strikethrough state, or null to use the
        default
        """
        ...


    def isStrikethrough(self) -> bool:
        """
        Returns whether this component is strikethrough. This uses the parent's
        setting if this component hasn't been set. False is returned if none of
        the parent chain has been set.

        Returns
        - whether the component is strikethrough
        """
        ...


    def isStrikethroughRaw(self) -> "Boolean":
        """
        Returns whether this component is strikethrough without checking the
        parents setting. May return null

        Returns
        - whether the component is strikethrough
        """
        ...


    def setObfuscated(self, obfuscated: "Boolean") -> None:
        """
        Set whether or not this component is obfuscated.

        Arguments
        - obfuscated: the new obfuscated state, or null to use the default
        """
        ...


    def isObfuscated(self) -> bool:
        """
        Returns whether this component is obfuscated. This uses the parent's
        setting if this component hasn't been set. False is returned if none of
        the parent chain has been set.

        Returns
        - whether the component is obfuscated
        """
        ...


    def isObfuscatedRaw(self) -> "Boolean":
        """
        Returns whether this component is obfuscated without checking the parents
        setting. May return null

        Returns
        - whether the component is obfuscated
        """
        ...


    def applyStyle(self, style: "ComponentStyle") -> None:
        """
        Apply the style from the given ComponentStyle to this component.
        
        Any style values that have been explicitly set in the style will be
        applied to this component. If a value is not set in the style, it will
        not override the style set in this component.

        Arguments
        - style: the style to apply
        """
        ...


    def setExtra(self, components: list["BaseComponent"]) -> None:
        ...


    def addExtra(self, text: str) -> None:
        """
        Appends a text element to the component. The text will inherit this
        component's formatting

        Arguments
        - text: the text to append
        """
        ...


    def addExtra(self, component: "BaseComponent") -> None:
        """
        Appends a component to the component. The text will inherit this
        component's formatting

        Arguments
        - component: the component to append
        """
        ...


    def hasStyle(self) -> bool:
        """
        Returns whether the component has any styling applied to it.

        Returns
        - Whether any styling is applied
        """
        ...


    def hasFormatting(self) -> bool:
        """
        Returns whether the component has any formatting or events applied to it

        Returns
        - Whether any formatting or events are applied
        """
        ...


    def toPlainText(self) -> str:
        """
        Converts the component into a string without any formatting

        Returns
        - the string as plain text
        """
        ...


    def toLegacyText(self) -> str:
        """
        Converts the component to a string that uses the old formatting codes
        (net.md_5.bungee.api.ChatColor.COLOR_CHAR

        Returns
        - the string in the old format
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingDeque

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Deque
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingDeque(ForwardingQueue, Deque):
    """
    A deque which forwards all its method calls to another deque. Subclasses should override one or
    more methods to modify the behavior of the backing deque as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingDeque` forward **indiscriminately** to the
    methods of the delegate. For example, overriding .add alone **will not** change the
    behavior of .offer which can lead to unexpected behavior. In this case, you should
    override `offer` as well.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingDeque`.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 12.0
    """

    def addFirst(self, e: "E") -> None:
        ...


    def addLast(self, e: "E") -> None:
        ...


    def descendingIterator(self) -> Iterator["E"]:
        ...


    def getFirst(self) -> "E":
        ...


    def getLast(self) -> "E":
        ...


    def offerFirst(self, e: "E") -> bool:
        ...


    def offerLast(self, e: "E") -> bool:
        ...


    def peekFirst(self) -> "E":
        ...


    def peekLast(self) -> "E":
        ...


    def pollFirst(self) -> "E":
        ...


    def pollLast(self) -> "E":
        ...


    def pop(self) -> "E":
        ...


    def push(self, e: "E") -> None:
        ...


    def removeFirst(self) -> "E":
        ...


    def removeLast(self) -> "E":
        ...


    def removeFirstOccurrence(self, o: "Object") -> bool:
        ...


    def removeLastOccurrence(self, o: "Object") -> bool:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.emitter.EmitterException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.emitter import *
from org.yaml.snakeyaml.error import YAMLException
from typing import Any, Callable, Iterable, Tuple


class EmitterException(YAMLException):
    """
    For emitter
    """

    def __init__(self, msg: str):
        """
        Create

        Arguments
        - msg: - text to show
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerItemMendEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import ExperienceOrb
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerItemMendEvent(PlayerEvent, Cancellable):
    """
    Represents when a player has an item repaired via the Mending enchantment.
    
    This event is fired directly before the PlayerExpChangeEvent, and the
    results of this event directly affect the PlayerExpChangeEvent.
    """

    def __init__(self, who: "Player", item: "ItemStack", slot: "EquipmentSlot", experienceOrb: "ExperienceOrb", repairAmount: int):
        ...


    def __init__(self, who: "Player", item: "ItemStack", experienceOrb: "ExperienceOrb", repairAmount: int):
        ...


    def getItem(self) -> "ItemStack":
        """
        Get the ItemStack to be repaired.
        
        This is not necessarily the item the player is holding.

        Returns
        - the item to be repaired
        """
        ...


    def getSlot(self) -> "EquipmentSlot":
        """
        Get the EquipmentSlot in which the repaired ItemStack
        may be found.

        Returns
        - the repaired slot
        """
        ...


    def getExperienceOrb(self) -> "ExperienceOrb":
        """
        Get the experience orb triggering the event.

        Returns
        - the experience orb
        """
        ...


    def getRepairAmount(self) -> int:
        """
        Get the amount the item is to be repaired.
        
        The default value is twice the value of the consumed experience orb
        or the remaining damage left on the item, whichever is smaller.

        Returns
        - how much damage will be repaired by the experience orb
        """
        ...


    def setRepairAmount(self, amount: int) -> None:
        """
        Set the amount the item will be repaired.
        
        Half of this value will be subtracted from the experience orb which initiated this event.

        Arguments
        - amount: how much damage will be repaired on the item
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.ReflectionAccessFilter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import ReflectionAccessFilterHelper
from java.lang.reflect import AccessibleObject
from typing import Any, Callable, Iterable, Tuple


class ReflectionAccessFilter:
    """
    Filter for determining whether reflection based serialization and deserialization is allowed for
    a class.
    
    A filter can be useful in multiple scenarios, for example when upgrading to newer Java
    versions which use the Java Platform Module System (JPMS). A filter then allows to FilterResult.BLOCK_INACCESSIBLE prevent making inaccessible members accessible, even if the used
    Java version might still allow illegal access (but logs a warning), or if `java` command
    line arguments are used to open the inaccessible packages to other parts of the application. This
    interface defines some convenience filters for this task, such as .BLOCK_INACCESSIBLE_JAVA.
    
    A filter can also be useful to prevent mixing model classes of a project with other non-model
    classes; the filter could FilterResult.BLOCK_ALL block all reflective access to
    non-model classes.
    
    A reflection access filter is similar to an ExclusionStrategy with the major
    difference that a filter will cause an exception to be thrown when access is disallowed while an
    exclusion strategy just skips fields and classes.

    See
    - GsonBuilder.addReflectionAccessFilter(ReflectionAccessFilter)

    Since
    - 2.9.1
    """

    BLOCK_INACCESSIBLE_JAVA = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isJavaType(rawClass) ? FilterResult.BLOCK_INACCESSIBLE : FilterResult.INDECISIVE;
        }
    
        @Override
        public String toString() {
            return "ReflectionAccessFilter#BLOCK_INACCESSIBLE_JAVA";
        }
    }
    """
    Blocks all reflection access to members of standard Java classes which are not accessible by
    default. However, reflection access is still allowed for classes for which all fields are
    accessible and which have an accessible no-args constructor (or for which an InstanceCreator has been registered).
    
    If this filter encounters a class other than a standard Java class it returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to help enforcing the access checks of Java Platform Module
    System. It allows detecting illegal access, even if the used Java version would only log a
    warning, or is configured to open packages for reflection. However, this filter **only works
    for Java 9 and higher**, when using an older Java version its functionality will be limited.
    
    Note that this filter might not cover all standard Java classes. Currently only classes in a
    `java.*` or `javax.*` package are considered. The set of detected classes might be
    expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_INACCESSIBLE
    """
    BLOCK_ALL_JAVA = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isJavaType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    
        @Override
        public String toString() {
            return "ReflectionAccessFilter#BLOCK_ALL_JAVA";
        }
    }
    """
    Blocks all reflection access to members of standard Java classes.
    
    If this filter encounters a class other than a standard Java class it returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation details of the Java
    platform and to help applications prepare for upgrading to the Java Platform Module System.
    
    Note that this filter might not cover all standard Java classes. Currently only classes in a
    `java.*` or `javax.*` package are considered. The set of detected classes might be
    expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """
    BLOCK_ALL_ANDROID = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isAndroidType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    
        @Override
        public String toString() {
            return "ReflectionAccessFilter#BLOCK_ALL_ANDROID";
        }
    }
    """
    Blocks all reflection access to members of standard Android classes.
    
    If this filter encounters a class other than a standard Android class it returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation details of the Android
    platform.
    
    Note that this filter might not cover all standard Android classes. Currently only classes
    in an `android.*` or `androidx.*` package, and standard Java classes in a `java.*` or `javax.*` package are considered. The set of detected classes might be
    expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """
    BLOCK_ALL_PLATFORM = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isAnyPlatformType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    
        @Override
        public String toString() {
            return "ReflectionAccessFilter#BLOCK_ALL_PLATFORM";
        }
    }
    """
    Blocks all reflection access to members of classes belonging to programming language platforms,
    such as Java, Android, Kotlin or Scala.
    
    If this filter encounters a class other than a standard platform class it returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation details of the
    platform classes.
    
    Note that this filter might not cover all platform classes. Currently it combines the
    filters .BLOCK_ALL_JAVA and .BLOCK_ALL_ANDROID, and checks for other
    language-specific platform classes like `kotlin.*`. The set of detected classes might be
    expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """


    def check(self, rawClass: type[Any]) -> "FilterResult":
        """
        Checks if reflection access should be allowed for a class.

        Arguments
        - rawClass: Class to check

        Returns
        - Result indicating whether reflection access is allowed
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Event
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockEvent(Event):
    """
    Represents a block related event.
    """

    def __init__(self, theBlock: "Block"):
        ...


    def getBlock(self) -> "Block":
        """
        Gets the block involved in this event.

        Returns
        - The Block which block is involved in this event
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.components.CustomModelDataComponent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Color
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory.meta.components import *
from typing import Any, Callable, Iterable, Tuple


class CustomModelDataComponent(ConfigurationSerializable):
    """
    Represents a component which adds custom model data.
    """

    def getFloats(self) -> list["Float"]:
        """
        Gets a list of the custom floats.

        Returns
        - unmodifiable list
        """
        ...


    def setFloats(self, floats: list["Float"]) -> None:
        """
        Sets a list of the custom floats.

        Arguments
        - floats: new list
        """
        ...


    def getFlags(self) -> list["Boolean"]:
        """
        Gets a list of the custom flags.

        Returns
        - unmodifiable list
        """
        ...


    def setFlags(self, flags: list["Boolean"]) -> None:
        """
        Sets a list of the custom flags.

        Arguments
        - flags: new list
        """
        ...


    def getStrings(self) -> list[str]:
        """
        Gets a list of the custom strings.

        Returns
        - unmodifiable list
        """
        ...


    def setStrings(self, strings: list[str]) -> None:
        """
        Sets a list of the custom strings.

        Arguments
        - strings: new list
        """
        ...


    def getColors(self) -> list["Color"]:
        """
        Gets a list of the custom colors.

        Returns
        - unmodifiable list
        """
        ...


    def setColors(self, colors: list["Color"]) -> None:
        """
        Sets a list of the custom colors.

        Arguments
        - colors: new list
        """
        ...



"""
Python module generated from Java source file com.google.common.io.Resources

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import MoreObjects
from com.google.common.collect import Lists
from com.google.common.io import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import IOException
from java.io import InputStream
from java.io import OutputStream
from java.net import URL
from java.nio.charset import Charset
from java.nio.charset import StandardCharsets
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Resources:
    """
    Provides utility methods for working with resources in the classpath. Note that even though these
    methods use URL parameters, they are usually not appropriate for HTTP or other
    non-classpath resources.

    Author(s)
    - Colin Decker

    Since
    - 1.0
    """

    @staticmethod
    def asByteSource(url: "URL") -> "ByteSource":
        """
        Returns a ByteSource that reads from the given URL.

        Since
        - 14.0
        """
        ...


    @staticmethod
    def asCharSource(url: "URL", charset: "Charset") -> "CharSource":
        """
        Returns a CharSource that reads from the given URL using the given character set.

        Since
        - 14.0
        """
        ...


    @staticmethod
    def toByteArray(url: "URL") -> list[int]:
        """
        Reads all bytes from a URL into a byte array.

        Arguments
        - url: the URL to read from

        Returns
        - a byte array containing all the bytes from the URL

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    @staticmethod
    def toString(url: "URL", charset: "Charset") -> str:
        """
        Reads all characters from a URL into a String, using the given character set.

        Arguments
        - url: the URL to read from
        - charset: the charset used to decode the input stream; see StandardCharsets for
            helpful predefined constants

        Returns
        - a string containing all the characters from the URL

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    @staticmethod
    def readLines(url: "URL", charset: "Charset", callback: "LineProcessor"["T"]) -> "T":
        """
        Streams lines from a URL, stopping when our callback returns False, or we have read all of the
        lines.

        Arguments
        - url: the URL to read from
        - charset: the charset used to decode the input stream; see StandardCharsets for
            helpful predefined constants
        - callback: the LineProcessor to use to handle the lines

        Returns
        - the output of processing the lines

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    @staticmethod
    def readLines(url: "URL", charset: "Charset") -> list[str]:
        """
        Reads all of the lines from a URL. The lines do not include line-termination characters, but do
        include other leading and trailing whitespace.
        
        This method returns a mutable `List`. For an `ImmutableList`, use `Resources.asCharSource(url, charset).readLines()`.

        Arguments
        - url: the URL to read from
        - charset: the charset used to decode the input stream; see StandardCharsets for
            helpful predefined constants

        Returns
        - a mutable List containing all the lines

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    @staticmethod
    def copy(from: "URL", to: "OutputStream") -> None:
        """
        Copies all bytes from a URL to an output stream.

        Arguments
        - from: the URL to read from
        - to: the output stream

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    @staticmethod
    def getResource(resourceName: str) -> "URL":
        """
        Returns a `URL` pointing to `resourceName` if the resource is found using the
        Thread.getContextClassLoader() context class loader. In simple environments, the
        context class loader will find resources from the class path. In environments where different
        threads can have different class loaders, for example app servers, the context class loader
        will typically have been set to an appropriate loader for the current thread.
        
        In the unusual case where the context class loader is null, the class loader that loaded
        this class (`Resources`) will be used instead.

        Raises
        - IllegalArgumentException: if the resource is not found
        """
        ...


    @staticmethod
    def getResource(contextClass: type[Any], resourceName: str) -> "URL":
        """
        Given a `resourceName` that is relative to `contextClass`, returns a `URL`
        pointing to the named resource.

        Raises
        - IllegalArgumentException: if the resource is not found
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.LinkedHashMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import WeakOuter
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.util import Arrays
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Spliterator
from java.util.function import Consumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class LinkedHashMultimap(LinkedHashMultimapGwtSerializationDependencies):
    """
    Implementation of `Multimap` that does not allow duplicate key-value entries and that
    returns collections whose iterators follow the ordering in which the data was added to the
    multimap.
    
    The collections returned by `keySet`, `keys`, and `asMap` iterate through
    the keys in the order they were first added to the multimap. Similarly, `get`, `removeAll`, and `replaceValues` return collections that iterate through the values in the
    order they were added. The collections generated by `entries` and `values` iterate
    across the key-value mappings in the order they were added to the multimap.
    
    The iteration ordering of the collections generated by `keySet`, `keys`, and
    `asMap` has a few subtleties. As long as the set of keys remains unchanged, adding or
    removing mappings does not affect the key iteration order. However, if you remove all values
    associated with a key and then add the key back to the multimap, that key will come last in the
    key iteration order.
    
    The multimap does not store duplicate key-value pairs. Adding a new key-value pair equal to an
    existing key-value pair has no effect.
    
    Keys and values may be null. All optional multimap methods are supported, and all returned
    views are modifiable.
    
    This class is not threadsafe when any concurrent operations update the multimap. Concurrent
    read operations will work correctly. To allow concurrent update operations, wrap your multimap
    with a call to Multimaps.synchronizedSetMultimap.
    
    **Warning:** Do not modify either a key *or a value* of a `LinkedHashMultimap`
    in a way that affects its Object.equals behavior. Undefined behavior and bugs will
    result.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multimap">`Multimap`</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "LinkedHashMultimap"["K", "V"]:
        """
        Creates a new, empty `LinkedHashMultimap` with the default initial capacities.
        """
        ...


    @staticmethod
    def create(expectedKeys: int, expectedValuesPerKey: int) -> "LinkedHashMultimap"["K", "V"]:
        """
        Constructs an empty `LinkedHashMultimap` with enough capacity to hold the specified
        numbers of keys and values without rehashing.

        Arguments
        - expectedKeys: the expected number of distinct keys
        - expectedValuesPerKey: the expected average number of values per key

        Raises
        - IllegalArgumentException: if `expectedKeys` or `expectedValuesPerKey` is
            negative
        """
        ...


    @staticmethod
    def create(multimap: "Multimap"["K", "V"]) -> "LinkedHashMultimap"["K", "V"]:
        """
        Constructs a `LinkedHashMultimap` with the same mappings as the specified multimap. If a
        key-value mapping appears multiple times in the input multimap, it only appears once in the
        constructed multimap. The new multimap has the same Multimap.entries() iteration order
        as the input multimap, except for excluding duplicate mappings.

        Arguments
        - multimap: the multimap whose contents are copied to this multimap
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> set["V"]:
        """
        
        
        If `values` is not empty and the multimap already contains a mapping for `key`,
        the `keySet()` ordering is unchanged. However, the provided values always come last in
        the .entries() and .values() iteration orderings.
        """
        ...


    def entries(self) -> set["Entry"["K", "V"]]:
        """
        Returns a set of all key-value pairs. Changes to the returned set will update the underlying
        multimap, and vice versa. The entries set does not support the `add` or `addAll`
        operations.
        
        The iterator generated by the returned set traverses the entries in the order they were
        added to the multimap.
        
        Each entry is an immutable snapshot of a key-value mapping in the multimap, taken at the
        time the entry is returned by a method call to the collection or its iterator.
        """
        ...


    def keySet(self) -> set["K"]:
        """
        Returns a view collection of all *distinct* keys contained in this multimap. Note that the
        key set contains a key if and only if this multimap maps that key to at least one value.
        
        The iterator generated by the returned set traverses the keys in the order they were first
        added to the multimap.
        
        Changes to the returned set will update the underlying multimap, and vice versa. However,
        *adding* to the returned set is not possible.
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a collection of all values in the multimap. Changes to the returned collection will
        update the underlying multimap, and vice versa.
        
        The iterator generated by the returned collection traverses the values in the order they
        were added to the multimap.
        """
        ...


    def clear(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.BlastingRecipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class BlastingRecipe(CookingRecipe):
    """
    Represents a campfire recipe.
    """

    def __init__(self, key: "NamespacedKey", result: "ItemStack", source: "Material", experience: float, cookingTime: int):
        ...


    def __init__(self, key: "NamespacedKey", result: "ItemStack", input: "RecipeChoice", experience: float, cookingTime: int):
        ...



"""
Python module generated from Java source file org.bukkit.inventory.ItemCraftResult

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class ItemCraftResult:
    """
    Container class containing the results of a Crafting event.
    
    This class makes no guarantees about the nature or mutability of the returned
    values.
    """

    def getResult(self) -> "ItemStack":
        """
        The resulting ItemStack that was crafted.

        Returns
        - ItemStack that was crafted.
        """
        ...


    def getResultingMatrix(self) -> list["ItemStack"]:
        """
        Gets the resulting matrix from the crafting operation.

        Returns
        - resulting matrix
        """
        ...


    def getOverflowItems(self) -> list["ItemStack"]:
        """
        Gets the overflowed items for items that don't fit back into the crafting
        matrix.

        Returns
        - overflow items
        """
        ...



"""
Python module generated from Java source file java.io.ByteArrayOutputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.nio.charset import Charset
from java.util import Arrays
from java.util import Objects
from jdk.internal.util import ArraysSupport
from typing import Any, Callable, Iterable, Tuple


class ByteArrayOutputStream(OutputStream):

    def __init__(self):
        """
        Creates a new `ByteArrayOutputStream`. The buffer capacity is
        initially 32 bytes, though its size increases if necessary.
        """
        ...


    def __init__(self, size: int):
        """
        Creates a new `ByteArrayOutputStream`, with a buffer capacity of
        the specified size, in bytes.

        Arguments
        - size: the initial size.

        Raises
        - IllegalArgumentException: if size is negative.
        """
        ...


    def write(self, b: int) -> None:
        """
        Writes the specified byte to this `ByteArrayOutputStream`.

        Arguments
        - b: the byte to be written.
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        """
        Writes `len` bytes from the specified byte array
        starting at offset `off` to this `ByteArrayOutputStream`.

        Arguments
        - b: the data.
        - off: the start offset in the data.
        - len: the number of bytes to write.

        Raises
        - NullPointerException: if `b` is `null`.
        - IndexOutOfBoundsException: if `off` is negative,
        `len` is negative, or `len` is greater than
        `b.length - off`
        """
        ...


    def writeBytes(self, b: list[int]) -> None:
        """
        Writes the complete contents of the specified byte array
        to this `ByteArrayOutputStream`.

        Arguments
        - b: the data.

        Raises
        - NullPointerException: if `b` is `null`.

        Since
        - 11

        Unknown Tags
        - This method is equivalent to .write(byte[],int,int)
        write(b, 0, b.length).
        """
        ...


    def writeTo(self, out: "OutputStream") -> None:
        """
        Writes the complete contents of this `ByteArrayOutputStream` to
        the specified output stream argument, as if by calling the output
        stream's write method using `out.write(buf, 0, count)`.

        Arguments
        - out: the output stream to which to write the data.

        Raises
        - NullPointerException: if `out` is `null`.
        - IOException: if an I/O error occurs.
        """
        ...


    def reset(self) -> None:
        """
        Resets the `count` field of this `ByteArrayOutputStream`
        to zero, so that all currently accumulated output in the
        output stream is discarded. The output stream can be used again,
        reusing the already allocated buffer space.

        See
        - java.io.ByteArrayInputStream.count
        """
        ...


    def toByteArray(self) -> list[int]:
        """
        Creates a newly allocated byte array. Its size is the current
        size of this output stream and the valid contents of the buffer
        have been copied into it.

        Returns
        - the current contents of this output stream, as a byte array.

        See
        - java.io.ByteArrayOutputStream.size()
        """
        ...


    def size(self) -> int:
        """
        Returns the current size of the buffer.

        Returns
        - the value of the `count` field, which is the number
                 of valid bytes in this output stream.

        See
        - java.io.ByteArrayOutputStream.count
        """
        ...


    def toString(self) -> str:
        """
        Converts the buffer's contents into a string decoding bytes using the
        platform's default character set. The length of the new `String`
        is a function of the character set, and hence may not be equal to the
        size of the buffer.
        
         This method always replaces malformed-input and unmappable-character
        sequences with the default replacement string for the platform's
        default character set. The java.nio.charset.CharsetDecoder
        class should be used when more control over the decoding process is
        required.

        Returns
        - String decoded from the buffer's contents.

        Since
        - 1.1
        """
        ...


    def toString(self, charsetName: str) -> str:
        """
        Converts the buffer's contents into a string by decoding the bytes using
        the named java.nio.charset.Charset charset.
        
         This method is equivalent to `.toString(charset)` that takes a
        java.nio.charset.Charset charset.
        
         An invocation of this method of the form
        
        ``` `ByteArrayOutputStream b = ...
             b.toString("UTF-8")`
        ```
        
        behaves in exactly the same way as the expression
        
        ``` `ByteArrayOutputStream b = ...
             b.toString(StandardCharsets.UTF_8)`
        ```

        Arguments
        - charsetName: the name of a supported
                java.nio.charset.Charset charset

        Returns
        - String decoded from the buffer's contents.

        Raises
        - UnsupportedEncodingException: If the named charset is not supported

        Since
        - 1.1
        """
        ...


    def toString(self, charset: "Charset") -> str:
        """
        Converts the buffer's contents into a string by decoding the bytes using
        the specified java.nio.charset.Charset charset. The length of the new
        `String` is a function of the charset, and hence may not be equal
        to the length of the byte array.
        
         This method always replaces malformed-input and unmappable-character
        sequences with the charset's default replacement string. The java.nio.charset.CharsetDecoder class should be used when more control
        over the decoding process is required.

        Arguments
        - charset: the java.nio.charset.Charset charset
                    to be used to decode the `bytes`

        Returns
        - String decoded from the buffer's contents.

        Since
        - 10
        """
        ...


    def toString(self, hibyte: int) -> str:
        """
        Creates a newly allocated string. Its size is the current size of
        the output stream and the valid contents of the buffer have been
        copied into it. Each character *c* in the resulting string is
        constructed from the corresponding element *b* in the byte
        array such that:
        <blockquote>````c == (char)(((hibyte & 0xff) << 8) | (b & 0xff))````</blockquote>

        Arguments
        - hibyte: the high byte of each resulting Unicode character.

        Returns
        - the current contents of the output stream, as a string.

        See
        - java.io.ByteArrayOutputStream.toString()

        Deprecated
        - This method does not properly convert bytes into characters.
        As of JDK&nbsp;1.1, the preferred way to do this is via the
        .toString(String charsetName) or .toString(Charset charset)
        method, which takes an encoding-name or charset argument,
        or the `toString()` method, which uses the platform's default
        character encoding.
        """
        ...


    def close(self) -> None:
        """
        Closing a `ByteArrayOutputStream` has no effect. The methods in
        this class can be called after the stream has been closed without
        generating an `IOException`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.MushroomCow

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from org.bukkit.potion import PotionEffect
from org.bukkit.potion import PotionEffectType
from typing import Any, Callable, Iterable, Tuple


class MushroomCow(Cow):
    """
    Represents a mushroom Cow
    """

    def hasEffectsForNextStew(self) -> bool:
        """
        Checks for the presence of custom potion effects to be applied to the
        next suspicious stew received from milking this MushroomCow.

        Returns
        - True if custom potion effects are applied to the stew
        """
        ...


    def getEffectsForNextStew(self) -> list["PotionEffect"]:
        """
        Gets an immutable list containing all custom potion effects applied to
        the next suspicious stew received from milking this MushroomCow.
        
        Plugins should check that hasCustomEffects() returns True before calling
        this method.

        Returns
        - an immutable list of custom potion effects
        """
        ...


    def addEffectToNextStew(self, effect: "PotionEffect", overwrite: bool) -> bool:
        """
        Adds a custom potion effect to be applied to the next suspicious stew
        received from milking this MushroomCow.

        Arguments
        - effect: the potion effect to add
        - overwrite: True if any existing effect of the same type should be
        overwritten

        Returns
        - True if the effects to be applied to the suspicious stew changed
        as a result of this call
        """
        ...


    def removeEffectFromNextStew(self, type: "PotionEffectType") -> bool:
        """
        Removes a custom potion effect from being applied to the next suspicious
        stew received from milking this MushroomCow.

        Arguments
        - type: the potion effect type to remove

        Returns
        - True if the effects to be applied to the suspicious stew changed
        as a result of this call
        """
        ...


    def hasEffectForNextStew(self, type: "PotionEffectType") -> bool:
        """
        Checks for a specific custom potion effect type to be applied to the next
        suspicious stew received from milking this MushroomCow.

        Arguments
        - type: the potion effect type to check for

        Returns
        - True if the suspicious stew to be generated has this effect
        """
        ...


    def clearEffectsForNextStew(self) -> None:
        """
        Removes all custom potion effects to be applied to the next suspicious
        stew received from milking this MushroomCow.
        """
        ...


    def getVariant(self) -> "Variant":
        """
        Get the variant of this cow.

        Returns
        - cow variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this cow.

        Arguments
        - variant: cow variant
        """
        ...


    class Variant(Enum):
        """
        Represents the variant of a cow - ie its color.
        """

        RED = 0
        """
        Red mushroom cow.
        """
        BROWN = 1
        """
        Brown mushroom cow.
        """



"""
Python module generated from Java source file org.bukkit.event.block.BlockDropItemEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.entity import Item
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockDropItemEvent(BlockEvent, Cancellable):
    """
    Called if a block broken by a player drops an item.
    
    If the block break is cancelled, this event won't be called.
    
    If isDropItems in BlockBreakEvent is set to False, this event won't be
    called.
    
    This event will also be called if the player breaks a multi block structure,
    for example a torch on top of a stone. Both items will have an event call.
    
    The Block is already broken as this event is called, so #getBlock() will be
    AIR in most cases. Use #getBlockState() for more Information about the broken
    block.
    """

    def __init__(self, block: "Block", blockState: "BlockState", player: "Player", items: list["Item"]):
        ...


    def getPlayer(self) -> "Player":
        """
        Gets the Player that is breaking the block involved in this event.

        Returns
        - The Player that is breaking the block involved in this event
        """
        ...


    def getBlockState(self) -> "BlockState":
        """
        Gets the BlockState of the block involved in this event before it was
        broken.

        Returns
        - The BlockState of the block involved in this event
        """
        ...


    def getItems(self) -> list["Item"]:
        """
        Gets list of the Item drops caused by the block break.
        
        This list is mutable - removing an item from it will cause it to not
        drop. It is not legal however to add new items to the list.

        Returns
        - The Item the block caused to drop
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations import DoNotMock
from com.google.j2objc.annotations import Weak
from com.google.j2objc.annotations import WeakOuter
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Arrays
from java.util import Comparator
from java.util import Iterator
from java.util import Spliterator
from java.util.function import BiConsumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableMultimap(BaseImmutableMultimap, Serializable):
    """
    A Multimap whose contents will never change, with many other important properties
    detailed at ImmutableCollection.
    
    **Warning:** avoid *direct* usage of ImmutableMultimap as a type (as with
    Multimap itself). Prefer subtypes such as ImmutableSetMultimap or ImmutableListMultimap, which have well-defined .equals semantics, thus avoiding a common
    source of bugs and confusion.
    
    **Note:** every ImmutableMultimap offers an .inverse view, so there is no
    need for a distinct `ImmutableBiMultimap` type.
    
    <a id="iteration"></a>
    
    **Key-grouped iteration.** All view collections follow the same iteration order. In all
    current implementations, the iteration order always keeps multiple entries with the same key
    together. Any creation method that would customarily respect insertion order (such as .copyOf(Multimap)) instead preserves key-grouped order by inserting entries for an existing key
    immediately after the last entry having that key.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def of() -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an empty multimap.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing a single entry.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in order.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in the "key-grouped" insertion
        order described in the <a href="#iteration">class documentation</a>.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in the "key-grouped" insertion
        order described in the <a href="#iteration">class documentation</a>.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the given entries, in the "key-grouped" insertion
        order described in the <a href="#iteration">class documentation</a>.
        """
        ...


    @staticmethod
    def builder() -> "Builder"["K", "V"]:
        """
        Returns a new builder. The generated builder is equivalent to the builder created by the Builder constructor.
        """
        ...


    @staticmethod
    def builderWithExpectedKeys(expectedKeys: int) -> "Builder"["K", "V"]:
        """
        Returns a new builder with a hint for how many distinct keys are expected to be added. The
        generated builder is equivalent to that returned by .builder, but may perform better if
        `expectedKeys` is a good estimate.

        Raises
        - IllegalArgumentException: if `expectedKeys` is negative

        Since
        - 33.3.0
        """
        ...


    @staticmethod
    def copyOf(multimap: "Multimap"["K", "V"]) -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the same mappings as `multimap`, in the
        "key-grouped" iteration order described in the class documentation.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if any key or value in `multimap` is null
        """
        ...


    @staticmethod
    def copyOf(entries: Iterable["Entry"["K", "V"]]) -> "ImmutableMultimap"["K", "V"]:
        """
        Returns an immutable multimap containing the specified entries. The returned multimap iterates
        over keys in the order they were first encountered in the input, and the values for each key
        are iterated in the order they were encountered.

        Raises
        - NullPointerException: if any key, value, or entry is null

        Since
        - 19.0
        """
        ...


    def removeAll(self, key: "Object") -> "ImmutableCollection"["V"]:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> "ImmutableCollection"["V"]:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def clear(self) -> None:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def get(self, key: "K") -> "ImmutableCollection"["V"]:
        """
        Returns an immutable collection of the values for the given key. If no mappings in the multimap
        have the provided key, an empty immutable collection is returned. The values are in the same
        order as the parameters used to build this multimap.
        """
        ...


    def inverse(self) -> "ImmutableMultimap"["V", "K"]:
        """
        Returns an immutable multimap which is the inverse of this one. For every key-value mapping in
        the original, the result will have a mapping with key and value reversed.

        Since
        - 11.0
        """
        ...


    def put(self, key: "K", value: "V") -> bool:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def putAll(self, key: "K", values: Iterable["V"]) -> bool:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def putAll(self, multimap: "Multimap"["K", "V"]) -> bool:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        """
        Guaranteed to throw an exception and leave the multimap unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def size(self) -> int:
        ...


    def keySet(self) -> "ImmutableSet"["K"]:
        """
        Returns an immutable set of the distinct keys in this multimap, in the same order as they
        appear in this multimap.
        """
        ...


    def asMap(self) -> "ImmutableMap"["K", Iterable["V"]]:
        """
        Returns an immutable map that associates each key with its corresponding values in the
        multimap. Keys and values appear in the same order as in this multimap.
        """
        ...


    def entries(self) -> "ImmutableCollection"["Entry"["K", "V"]]:
        """
        Returns an immutable collection of all key-value pairs in the multimap.
        """
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def keys(self) -> "ImmutableMultiset"["K"]:
        """
        Returns an immutable multiset containing all the keys in this multimap, in the same order and
        with the same frequencies as they appear in this multimap; to get only a single occurrence of
        each key, use .keySet.
        """
        ...


    def values(self) -> "ImmutableCollection"["V"]:
        """
        Returns an immutable collection of the values in this multimap. Its iterator traverses the
        values for the first key, the values for the second key, and so on.
        """
        ...


    class Builder:
        """
        A builder for creating immutable multimap instances, especially `public static final`
        multimaps ("constant multimaps"). Example:
        
        ````static final Multimap<String, Integer> STRING_TO_INTEGER_MULTIMAP =
            new ImmutableMultimap.Builder<String, Integer>()
                .put("one", 1)
                .putAll("several", 1, 2, 3)
                .putAll("many", 1, 2, 3, 4, 5)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple multimaps in series. Each multimap contains the key-value mappings in the previously
        created multimaps.

        Since
        - 2.0
        """

        def __init__(self):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableMultimap.builder.
            """
            ...


        def expectedValuesPerKey(self, expectedValuesPerKey: int) -> "Builder"["K", "V"]:
            """
            Provides a hint for how many values will be associated with each key newly added to the
            builder after this call. This does not change semantics, but may improve performance if
            `expectedValuesPerKey` is a good estimate.
            
            This may be called more than once; each newly added key will use the most recent call to
            .expectedValuesPerKey as its hint.

            Raises
            - IllegalArgumentException: if `expectedValuesPerKey` is negative

            Since
            - 33.3.0
            """
            ...


        def put(self, key: "K", value: "V") -> "Builder"["K", "V"]:
            """
            Adds a key-value mapping to the built multimap.
            """
            ...


        def put(self, entry: "Entry"["K", "V"]) -> "Builder"["K", "V"]:
            """
            Adds an entry to the built multimap.

            Since
            - 11.0
            """
            ...


        def putAll(self, entries: Iterable["Entry"["K", "V"]]) -> "Builder"["K", "V"]:
            """
            Adds entries to the built multimap.

            Since
            - 19.0
            """
            ...


        def putAll(self, key: "K", values: Iterable["V"]) -> "Builder"["K", "V"]:
            """
            Stores a collection of values with the same key in the built multimap.

            Raises
            - NullPointerException: if `key`, `values`, or any element in `values`
                is null. The builder is left in an invalid state.
            """
            ...


        def putAll(self, key: "K", *values: Tuple["V", ...]) -> "Builder"["K", "V"]:
            """
            Stores an array of values with the same key in the built multimap.

            Raises
            - NullPointerException: if the key or any value is null. The builder is left in an
                invalid state.
            """
            ...


        def putAll(self, multimap: "Multimap"["K", "V"]) -> "Builder"["K", "V"]:
            """
            Stores another multimap's entries in the built multimap. The generated multimap's key and
            value orderings correspond to the iteration ordering of the `multimap.asMap()` view,
            with new keys and values following any existing keys and values.

            Raises
            - NullPointerException: if any key or value in `multimap` is null. The builder is
                left in an invalid state.
            """
            ...


        def orderKeysBy(self, keyComparator: "Comparator"["K"]) -> "Builder"["K", "V"]:
            """
            Specifies the ordering of the generated multimap's keys.

            Since
            - 8.0
            """
            ...


        def orderValuesBy(self, valueComparator: "Comparator"["V"]) -> "Builder"["K", "V"]:
            """
            Specifies the ordering of the generated multimap's values for each key.

            Since
            - 8.0
            """
            ...


        def build(self) -> "ImmutableMultimap"["K", "V"]:
            """
            Returns a newly-created immutable multimap.
            """
            ...



from .Tag import Tag
from .CollectionNode import CollectionNode
from .SequenceNode import SequenceNode
from .NodeId import NodeId
from .AnchorNode import AnchorNode
from .Node import Node
from .NodeTuple import NodeTuple
from .MappingNode import MappingNode
from .ScalarNode import ScalarNode


"""
Python module generated from Java source file com.google.common.primitives.UnsignedInteger

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.primitives import *
from java.math import BigInteger
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class UnsignedInteger(Number, Comparable):
    """
    A wrapper class for unsigned `int` values, supporting arithmetic operations.
    
    In some cases, when speed is more important than code readability, it may be faster simply to
    treat primitive `int` values as unsigned, using the methods from UnsignedInts.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/PrimitivesExplained#unsigned-support">unsigned
    primitive utilities</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 11.0
    """

    ZERO = fromIntBits(0)
    ONE = fromIntBits(1)
    MAX_VALUE = fromIntBits(-1)


    @staticmethod
    def fromIntBits(bits: int) -> "UnsignedInteger":
        """
        Returns an `UnsignedInteger` corresponding to a given bit representation. The argument is
        interpreted as an unsigned 32-bit value. Specifically, the sign bit of `bits` is
        interpreted as a normal bit, and all other bits are treated as usual.
        
        If the argument is nonnegative, the returned result will be equal to `bits`,
        otherwise, the result will be equal to `2^32 + bits`.
        
        To represent unsigned decimal constants, consider .valueOf(long) instead.

        Since
        - 14.0
        """
        ...


    @staticmethod
    def valueOf(value: int) -> "UnsignedInteger":
        """
        Returns an `UnsignedInteger` that is equal to `value`, if possible. The inverse
        operation of .longValue().
        """
        ...


    @staticmethod
    def valueOf(value: "BigInteger") -> "UnsignedInteger":
        """
        Returns a `UnsignedInteger` representing the same value as the specified BigInteger. This is the inverse operation of .bigIntegerValue().

        Raises
        - IllegalArgumentException: if `value` is negative or `value >= 2^32`
        """
        ...


    @staticmethod
    def valueOf(string: str) -> "UnsignedInteger":
        """
        Returns an `UnsignedInteger` holding the value of the specified `String`, parsed as
        an unsigned `int` value.

        Raises
        - NumberFormatException: if the string does not contain a parsable unsigned `int`
            value
        """
        ...


    @staticmethod
    def valueOf(string: str, radix: int) -> "UnsignedInteger":
        """
        Returns an `UnsignedInteger` holding the value of the specified `String`, parsed as
        an unsigned `int` value in the specified radix.

        Raises
        - NumberFormatException: if the string does not contain a parsable unsigned `int`
            value
        """
        ...


    def plus(self, val: "UnsignedInteger") -> "UnsignedInteger":
        """
        Returns the result of adding this and `val`. If the result would have more than 32 bits,
        returns the low 32 bits of the result.

        Since
        - 14.0
        """
        ...


    def minus(self, val: "UnsignedInteger") -> "UnsignedInteger":
        """
        Returns the result of subtracting this and `val`. If the result would be negative,
        returns the low 32 bits of the result.

        Since
        - 14.0
        """
        ...


    def times(self, val: "UnsignedInteger") -> "UnsignedInteger":
        """
        Returns the result of multiplying this and `val`. If the result would have more than 32
        bits, returns the low 32 bits of the result.

        Since
        - 14.0
        """
        ...


    def dividedBy(self, val: "UnsignedInteger") -> "UnsignedInteger":
        """
        Returns the result of dividing this by `val`.

        Raises
        - ArithmeticException: if `val` is zero

        Since
        - 14.0
        """
        ...


    def mod(self, val: "UnsignedInteger") -> "UnsignedInteger":
        """
        Returns this mod `val`.

        Raises
        - ArithmeticException: if `val` is zero

        Since
        - 14.0
        """
        ...


    def intValue(self) -> int:
        """
        Returns the value of this `UnsignedInteger` as an `int`. This is an inverse
        operation to .fromIntBits.
        
        Note that if this `UnsignedInteger` holds a value `>= 2^31`, the returned value
        will be equal to `this - 2^32`.
        """
        ...


    def longValue(self) -> int:
        """
        Returns the value of this `UnsignedInteger` as a `long`.
        """
        ...


    def floatValue(self) -> float:
        """
        Returns the value of this `UnsignedInteger` as a `float`, analogous to a widening
        primitive conversion from `int` to `float`, and correctly rounded.
        """
        ...


    def doubleValue(self) -> float:
        """
        Returns the value of this `UnsignedInteger` as a `float`, analogous to a widening
        primitive conversion from `int` to `double`, and correctly rounded.
        """
        ...


    def bigIntegerValue(self) -> "BigInteger":
        """
        Returns the value of this `UnsignedInteger` as a BigInteger.
        """
        ...


    def compareTo(self, other: "UnsignedInteger") -> int:
        """
        Compares this unsigned integer to another unsigned integer. Returns `0` if they are
        equal, a negative number if `this < other`, and a positive number if `this >
        other`.
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        """
        Returns a string representation of the `UnsignedInteger` value, in base 10.
        """
        ...


    def toString(self, radix: int) -> str:
        """
        Returns a string representation of the `UnsignedInteger` value, in base `radix`. If
        `radix < Character.MIN_RADIX` or `radix > Character.MAX_RADIX`, the radix `10` is used.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityChangeBlockEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block.data import BlockData
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityChangeBlockEvent(EntityEvent, Cancellable):
    """
    Called when any Entity changes a block and a more specific event is not available.
    """

    def __init__(self, what: "Entity", block: "Block", to: "BlockData"):
        ...


    def getBlock(self) -> "Block":
        """
        Gets the block the entity is changing

        Returns
        - the block that is changing
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getTo(self) -> "Material":
        """
        Gets the Material that the block is changing into

        Returns
        - the material that the block is changing into
        """
        ...


    def getBlockData(self) -> "BlockData":
        """
        Gets the data for the block that would be changed into

        Returns
        - the data for the block that would be changed into
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.LingeringPotionSplashEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import AreaEffectCloud
from org.bukkit.entity import Entity
from org.bukkit.entity import ThrownPotion
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class LingeringPotionSplashEvent(ProjectileHitEvent, Cancellable):
    """
    Called when a splash potion hits an area
    """

    def __init__(self, potion: "ThrownPotion", entity: "AreaEffectCloud"):
        ...


    def __init__(self, potion: "ThrownPotion", hitEntity: "Entity", hitBlock: "Block", hitFace: "BlockFace", entity: "AreaEffectCloud"):
        ...


    def getEntity(self) -> "ThrownPotion":
        ...


    def getAreaEffectCloud(self) -> "AreaEffectCloud":
        """
        Gets the AreaEffectCloud spawned

        Returns
        - The spawned AreaEffectCloud
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.entity.Allay

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import *
from org.bukkit.event.entity import CreatureSpawnEvent
from org.bukkit.inventory import InventoryHolder
from typing import Any, Callable, Iterable, Tuple


class Allay(Creature, InventoryHolder):
    """
    An Allay.
    """

    def canDuplicate(self) -> bool:
        """
        Gets if the allay can duplicate.
        
        **Note:** Duplication is based when the
        .getDuplicationCooldown its lower than zero.

        Returns
        - if the allay can duplicate itself.
        """
        ...


    def setCanDuplicate(self, canDuplicate: bool) -> None:
        """
        Sets if the allay can duplicate.
        
        **Note:** this value can be overridden later by
        .getDuplicationCooldown if is lower than zero. You can also use
        .setDuplicationCooldown to allow the allay to duplicate

        Arguments
        - canDuplicate: if the allay can duplicate itself
        """
        ...


    def getDuplicationCooldown(self) -> int:
        """
        Gets the cooldown for duplicating the allay.

        Returns
        - the time in ticks when allay can duplicate
        """
        ...


    def setDuplicationCooldown(self, cooldown: int) -> None:
        """
        Sets the cooldown before the allay can duplicate again.

        Arguments
        - cooldown: the cooldown, use a negative number to deny allay to
        duplicate again.
        """
        ...


    def resetDuplicationCooldown(self) -> None:
        """
        Reset the cooldown for duplication.
        
        This will set the cooldown ticks to the same value as is set after an
        Allay has duplicated.
        """
        ...


    def isDancing(self) -> bool:
        """
        Gets if the allay is dancing.

        Returns
        - `True` if it is dancing, False otherwise.
        """
        ...


    def startDancing(self, location: "Location") -> None:
        """
        Causes the allay to start dancing because of the provided jukebox
        location.

        Arguments
        - location: the location of the jukebox

        Raises
        - IllegalArgumentException: if the block at the location is not a
        jukebox
        """
        ...


    def startDancing(self) -> None:
        """
        Force sets the dancing status of the allay.
        
        **Note:** This method forces the allay to dance, ignoring any nearby
        jukebox being required.
        """
        ...


    def stopDancing(self) -> None:
        """
        Makes the allay stop dancing.
        """
        ...


    def duplicateAllay(self) -> "Allay":
        """
        This make the current allay duplicate itself without dance or item
        necessary.
        **Note:** this will fire a CreatureSpawnEvent

        Returns
        - the new entity Allay or null if the spawn was cancelled
        """
        ...


    def getJukebox(self) -> "Location":
        """
        Gets the jukebox the allay is set to dance to.

        Returns
        - the location of the jukebox to dance if it exists
        """
        ...



"""
Python module generated from Java source file com.google.common.io.LineBuffer

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class LineBuffer:
    """
    Package-protected abstract class that implements the line reading algorithm used by LineReader. Line separators are per java.io.BufferedReader: line feed, carriage return,
    or carriage return followed immediately by a linefeed.
    
    Subclasses must implement .handleLine, call .add to pass character data, and
    call .finish at the end of stream.

    Author(s)
    - Chris Nokleberg

    Since
    - 1.0
    """





"""
Python module generated from Java source file org.bukkit.event.server.MapInitializeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from org.bukkit.map import MapView
from typing import Any, Callable, Iterable, Tuple


class MapInitializeEvent(ServerEvent):
    """
    Called when a map is initialized.
    """

    def __init__(self, mapView: "MapView"):
        ...


    def getMap(self) -> "MapView":
        """
        Gets the map initialized in this event.

        Returns
        - Map for this event
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .AclEntry import AclEntry
from .AclEntryPermission import AclEntryPermission
from .FileAttribute import FileAttribute
from .PosixFilePermissions import PosixFilePermissions
from .UserPrincipal import UserPrincipal
from .BasicFileAttributeView import BasicFileAttributeView
from .BasicFileAttributes import BasicFileAttributes
from .FileTime import FileTime


"""
Python module generated from Java source file com.google.common.util.concurrent.SimpleTimeLimiter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import ObjectArrays
from com.google.common.collect import Sets
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.lang.reflect import InvocationHandler
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from java.lang.reflect import Proxy
from java.util.concurrent import Callable
from java.util.concurrent import ExecutionException
from java.util.concurrent import ExecutorService
from java.util.concurrent import Executors
from java.util.concurrent import Future
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SimpleTimeLimiter(TimeLimiter):
    """
    A TimeLimiter that runs method calls in the background using an ExecutorService. If the
    time limit expires for a given method call, the thread running the call will be interrupted.

    Author(s)
    - Jens Nyman

    Since
    - 1.0
    """

    @staticmethod
    def create(executor: "ExecutorService") -> "SimpleTimeLimiter":
        """
        Creates a TimeLimiter instance using the given executor service to execute method calls.
        
        **Warning:** using a bounded executor may be counterproductive! If the thread pool fills
        up, any time callers spend waiting for a thread may count toward their time limit, and in this
        case the call may even time out before the target method is ever invoked.

        Arguments
        - executor: the ExecutorService that will execute the method calls on the target objects;
            for example, a Executors.newCachedThreadPool().

        Since
        - 22.0
        """
        ...


    def newProxy(self, target: "T", interfaceType: type["T"], timeoutDuration: int, timeoutUnit: "TimeUnit") -> "T":
        ...


    def callWithTimeout(self, callable: "Callable"["T"], timeoutDuration: int, timeoutUnit: "TimeUnit") -> "T":
        ...


    def callUninterruptiblyWithTimeout(self, callable: "Callable"["T"], timeoutDuration: int, timeoutUnit: "TimeUnit") -> "T":
        ...


    def runWithTimeout(self, runnable: "Runnable", timeoutDuration: int, timeoutUnit: "TimeUnit") -> None:
        ...


    def runUninterruptiblyWithTimeout(self, runnable: "Runnable", timeoutDuration: int, timeoutUnit: "TimeUnit") -> None:
        ...



"""
Python module generated from Java source file java.net.URI

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.net import *
from java.nio.charset import CharacterCodingException
from java.nio.charset import CharsetDecoder
from java.nio.charset import CharsetEncoder
from java.nio.charset import CoderResult
from java.nio.charset import CodingErrorAction
from java.nio.file import Path
from java.text import Normalizer
from jdk.internal.access import JavaNetUriAccess
from jdk.internal.access import SharedSecrets
from sun.nio.cs import UTF_8
from typing import Any, Callable, Iterable, Tuple


class URI(Comparable, Serializable):

    def __init__(self, str: str):
        """
        Constructs a URI by parsing the given string.
        
         This constructor parses the given string exactly as specified by the
        grammar in <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        Appendix&nbsp;A, ***except for the following deviations:*** 
        
        
        
          -  An empty authority component is permitted as long as it is
          followed by a non-empty path, a query component, or a fragment
          component.  This allows the parsing of URIs such as
          `"file:///foo/bar"`, which seems to be the intent of
          RFC&nbsp;2396 although the grammar does not permit it.  If the
          authority component is empty then the user-information, host, and port
          components are undefined. 
        
          -  Empty relative paths are permitted; this seems to be the
          intent of RFC&nbsp;2396 although the grammar does not permit it.  The
          primary consequence of this deviation is that a standalone fragment
          such as `".foo"` parses as a relative URI with an empty path
          and the given fragment, and can be usefully <a
          href="#resolve-frag">resolved</a> against a base URI.
        
          -  IPv4 addresses in host components are parsed rigorously, as
          specified by <a
          href="http://www.ietf.org/rfc/rfc2732.txt">RFC&nbsp;2732</a>: Each
          element of a dotted-quad address must contain no more than three
          decimal digits.  Each element is further constrained to have a value
          no greater than 255. 
        
          -   Hostnames in host components that comprise only a single
          domain label are permitted to start with an *alphanum*
          character. This seems to be the intent of <a
          href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>
          section&nbsp;3.2.2 although the grammar does not permit it. The
          consequence of this deviation is that the authority component of a
          hierarchical URI such as `s://123`, will parse as a server-based
          authority. 
        
          -  IPv6 addresses are permitted for the host component.  An IPv6
          address must be enclosed in square brackets (`'['` and
          `']'`) as specified by <a
          href="http://www.ietf.org/rfc/rfc2732.txt">RFC&nbsp;2732</a>.  The
          IPv6 address itself must parse according to <a
          href="http://www.ietf.org/rfc/rfc2373.txt">RFC&nbsp;2373</a>.  IPv6
          addresses are further constrained to describe no more than sixteen
          bytes of address information, a constraint implicit in RFC&nbsp;2373
          but not expressible in the grammar. 
        
          -  Characters in the *other* category are permitted wherever
          RFC&nbsp;2396 permits *escaped* octets, that is, in the
          user-information, path, query, and fragment components, as well as in
          the authority component if the authority is registry-based.  This
          allows URIs to contain Unicode characters beyond those in the US-ASCII
          character set. 
        

        Arguments
        - str: The string to be parsed into a URI

        Raises
        - NullPointerException: If `str` is `null`
        - URISyntaxException: If the given string violates RFC&nbsp;2396, as augmented
                 by the above deviations
        """
        ...


    def __init__(self, scheme: str, userInfo: str, host: str, port: int, path: str, query: str, fragment: str):
        """
        Constructs a hierarchical URI from the given components.
        
         If a scheme is given then the path, if also given, must either be
        empty or begin with a slash character (`'/'`).  Otherwise a
        component of the new URI may be left undefined by passing `null`
        for the corresponding parameter or, in the case of the `port`
        parameter, by passing `-1`.
        
         This constructor first builds a URI string from the given components
        according to the rules specified in <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        section&nbsp;5.2, step&nbsp;7: 
        
        <ol>
        
          -  Initially, the result string is empty. 
        
          -  If a scheme is given then it is appended to the result,
          followed by a colon character (`':'`).  
        
          -  If user information, a host, or a port are given then the
          string `"//"` is appended.  
        
          -  If user information is given then it is appended, followed by
          a commercial-at character (`'@'`).  Any character not in the
          *unreserved*, *punct*, *escaped*, or *other*
          categories is <a href="#quote">quoted</a>.  
        
          -  If a host is given then it is appended.  If the host is a
          literal IPv6 address but is not enclosed in square brackets
          (`'['` and `']'`) then the square brackets are added.
          
        
          -  If a port number is given then a colon character
          (`':'`) is appended, followed by the port number in decimal.
          
        
          -  If a path is given then it is appended.  Any character not in
          the *unreserved*, *punct*, *escaped*, or *other*
          categories, and not equal to the slash character (`'/'`) or the
          commercial-at character (`'@'`), is quoted.  
        
          -  If a query is given then a question-mark character
          (`'?'`) is appended, followed by the query.  Any character that
          is not a <a href="#legal-chars">legal URI character</a> is quoted.
          
        
          -  Finally, if a fragment is given then a hash character
          (`'.'`) is appended, followed by the fragment.  Any character
          that is not a legal URI character is quoted.  
        
        </ol>
        
         The resulting URI string is then parsed as if by invoking the .URI(String) constructor and then invoking the .parseServerAuthority() method upon the result; this may cause a URISyntaxException to be thrown.  

        Arguments
        - scheme: Scheme name
        - userInfo: User name and authorization information
        - host: Host name
        - port: Port number
        - path: Path
        - query: Query
        - fragment: Fragment

        Raises
        - URISyntaxException: If both a scheme and a path are given but the path is relative,
                if the URI string constructed from the given components violates
                RFC&nbsp;2396, or if the authority component of the string is
                present but cannot be parsed as a server-based authority
        """
        ...


    def __init__(self, scheme: str, authority: str, path: str, query: str, fragment: str):
        """
        Constructs a hierarchical URI from the given components.
        
         If a scheme is given then the path, if also given, must either be
        empty or begin with a slash character (`'/'`).  Otherwise a
        component of the new URI may be left undefined by passing `null`
        for the corresponding parameter.
        
         This constructor first builds a URI string from the given components
        according to the rules specified in <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        section&nbsp;5.2, step&nbsp;7: 
        
        <ol>
        
          -  Initially, the result string is empty.  
        
          -  If a scheme is given then it is appended to the result,
          followed by a colon character (`':'`).  
        
          -  If an authority is given then the string `"//"` is
          appended, followed by the authority.  If the authority contains a
          literal IPv6 address then the address must be enclosed in square
          brackets (`'['` and `']'`).  Any character not in the
          *unreserved*, *punct*, *escaped*, or *other*
          categories, and not equal to the commercial-at character
          (`'@'`), is <a href="#quote">quoted</a>.  
        
          -  If a path is given then it is appended.  Any character not in
          the *unreserved*, *punct*, *escaped*, or *other*
          categories, and not equal to the slash character (`'/'`) or the
          commercial-at character (`'@'`), is quoted.  
        
          -  If a query is given then a question-mark character
          (`'?'`) is appended, followed by the query.  Any character that
          is not a <a href="#legal-chars">legal URI character</a> is quoted.
          
        
          -  Finally, if a fragment is given then a hash character
          (`'.'`) is appended, followed by the fragment.  Any character
          that is not a legal URI character is quoted.  
        
        </ol>
        
         The resulting URI string is then parsed as if by invoking the .URI(String) constructor and then invoking the .parseServerAuthority() method upon the result; this may cause a URISyntaxException to be thrown.  

        Arguments
        - scheme: Scheme name
        - authority: Authority
        - path: Path
        - query: Query
        - fragment: Fragment

        Raises
        - URISyntaxException: If both a scheme and a path are given but the path is relative,
                if the URI string constructed from the given components violates
                RFC&nbsp;2396, or if the authority component of the string is
                present but cannot be parsed as a server-based authority
        """
        ...


    def __init__(self, scheme: str, host: str, path: str, fragment: str):
        """
        Constructs a hierarchical URI from the given components.
        
         A component may be left undefined by passing `null`.
        
         This convenience constructor works as if by invoking the
        seven-argument constructor as follows:
        
        <blockquote>
        `new` .URI(String, String, String, int, String, String, String)
        URI`(scheme, null, host, -1, path, null, fragment);`
        </blockquote>

        Arguments
        - scheme: Scheme name
        - host: Host name
        - path: Path
        - fragment: Fragment

        Raises
        - URISyntaxException: If the URI string constructed from the given components
                 violates RFC&nbsp;2396
        """
        ...


    def __init__(self, scheme: str, ssp: str, fragment: str):
        """
        Constructs a URI from the given components.
        
         A component may be left undefined by passing `null`.
        
         This constructor first builds a URI in string form using the given
        components as follows:  
        
        <ol>
        
          -  Initially, the result string is empty.  
        
          -  If a scheme is given then it is appended to the result,
          followed by a colon character (`':'`).  
        
          -  If a scheme-specific part is given then it is appended.  Any
          character that is not a <a href="#legal-chars">legal URI character</a>
          is <a href="#quote">quoted</a>.  
        
          -  Finally, if a fragment is given then a hash character
          (`'.'`) is appended to the string, followed by the fragment.
          Any character that is not a legal URI character is quoted.  
        
        </ol>
        
         The resulting URI string is then parsed in order to create the new
        URI instance as if by invoking the .URI(String) constructor;
        this may cause a URISyntaxException to be thrown.  

        Arguments
        - scheme: Scheme name
        - ssp: Scheme-specific part
        - fragment: Fragment

        Raises
        - URISyntaxException: If the URI string constructed from the given components
                 violates RFC&nbsp;2396
        """
        ...


    @staticmethod
    def create(str: str) -> "URI":
        """
        Creates a URI by parsing the given string.
        
         This convenience factory method works as if by invoking the .URI(String) constructor; any URISyntaxException thrown by the
        constructor is caught and wrapped in a new IllegalArgumentException object, which is then thrown.
        
         This method is provided for use in situations where it is known that
        the given string is a legal URI, for example for URI constants declared
        within a program, and so it would be considered a programming error
        for the string not to parse as such.  The constructors, which throw
        URISyntaxException directly, should be used in situations where a
        URI is being constructed from user input or from some other source that
        may be prone to errors.  

        Arguments
        - str: The string to be parsed into a URI

        Returns
        - The new URI

        Raises
        - NullPointerException: If `str` is `null`
        - IllegalArgumentException: If the given string violates RFC&nbsp;2396
        """
        ...


    def parseServerAuthority(self) -> "URI":
        """
        Attempts to parse this URI's authority component, if defined, into
        user-information, host, and port components.
        
         If this URI's authority component has already been recognized as
        being server-based then it will already have been parsed into
        user-information, host, and port components.  In this case, or if this
        URI has no authority component, this method simply returns this URI.
        
         Otherwise this method attempts once more to parse the authority
        component into user-information, host, and port components, and throws
        an exception describing why the authority component could not be parsed
        in that way.
        
         This method is provided because the generic URI syntax specified in
        <a href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>
        cannot always distinguish a malformed server-based authority from a
        legitimate registry-based authority.  It must therefore treat some
        instances of the former as instances of the latter.  The authority
        component in the URI string `"//foo:bar"`, for example, is not a
        legal server-based authority but it is legal as a registry-based
        authority.
        
         In many common situations, for example when working URIs that are
        known to be either URNs or URLs, the hierarchical URIs being used will
        always be server-based.  They therefore must either be parsed as such or
        treated as an error.  In these cases a statement such as
        
        <blockquote>
        `URI`*u*`= new URI(str).parseServerAuthority();`
        </blockquote>
        
         can be used to ensure that *u* always refers to a URI that, if
        it has an authority component, has a server-based authority with proper
        user-information, host, and port components.  Invoking this method also
        ensures that if the authority could not be parsed in that way then an
        appropriate diagnostic message can be issued based upon the exception
        that is thrown. 

        Returns
        - A URI whose authority field has been parsed
                 as a server-based authority

        Raises
        - URISyntaxException: If the authority component of this URI is defined
                 but cannot be parsed as a server-based authority
                 according to RFC&nbsp;2396
        """
        ...


    def normalize(self) -> "URI":
        """
        Normalizes this URI's path.
        
         If this URI is opaque, or if its path is already in normal form,
        then this URI is returned.  Otherwise a new URI is constructed that is
        identical to this URI except that its path is computed by normalizing
        this URI's path in a manner consistent with <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        section&nbsp;5.2, step&nbsp;6, sub-steps&nbsp;c through&nbsp;f; that is:
        
        
        <ol>
        
          -  All `"."` segments are removed. 
        
          -  If a `".."` segment is preceded by a non-`".."`
          segment then both of these segments are removed.  This step is
          repeated until it is no longer applicable. 
        
          -  If the path is relative, and if its first segment contains a
          colon character (`':'`), then a `"."` segment is
          prepended.  This prevents a relative URI with a path such as
          `"a:b/c/d"` from later being re-parsed as an opaque URI with a
          scheme of `"a"` and a scheme-specific part of `"b/c/d"`.
          ***(Deviation from RFC&nbsp;2396)*** 
        
        </ol>
        
         A normalized path will begin with one or more `".."` segments
        if there were insufficient non-`".."` segments preceding them to
        allow their removal.  A normalized path will begin with a `"."`
        segment if one was inserted by step 3 above.  Otherwise, a normalized
        path will not contain any `"."` or `".."` segments. 

        Returns
        - A URI equivalent to this URI,
                 but whose path is in normal form
        """
        ...


    def resolve(self, uri: "URI") -> "URI":
        """
        Resolves the given URI against this URI.
        
         If the given URI is already absolute, or if this URI is opaque, then
        the given URI is returned.
        
        <a id="resolve-frag"></a> If the given URI's fragment component is
        defined, its path component is empty, and its scheme, authority, and
        query components are undefined, then a URI with the given fragment but
        with all other components equal to those of this URI is returned.  This
        allows a URI representing a standalone fragment reference, such as
        `".foo"`, to be usefully resolved against a base URI.
        
         Otherwise this method constructs a new hierarchical URI in a manner
        consistent with <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        section&nbsp;5.2; that is: 
        
        <ol>
        
          -  A new URI is constructed with this URI's scheme and the given
          URI's query and fragment components. 
        
          -  If the given URI has an authority component then the new URI's
          authority and path are taken from the given URI. 
        
          -  Otherwise the new URI's authority component is copied from
          this URI, and its path is computed as follows: 
        
          <ol>
        
            -  If the given URI's path is absolute then the new URI's path
            is taken from the given URI. 
        
            -  Otherwise the given URI's path is relative, and so the new
            URI's path is computed by resolving the path of the given URI
            against the path of this URI.  This is done by concatenating all but
            the last segment of this URI's path, if any, with the given URI's
            path and then normalizing the result as if by invoking the .normalize() normalize method. 
        
          </ol>
        
        </ol>
        
         The result of this method is absolute if, and only if, either this
        URI is absolute or the given URI is absolute.  

        Arguments
        - uri: The URI to be resolved against this URI

        Returns
        - The resulting URI

        Raises
        - NullPointerException: If `uri` is `null`
        """
        ...


    def resolve(self, str: str) -> "URI":
        """
        Constructs a new URI by parsing the given string and then resolving it
        against this URI.
        
         This convenience method works as if invoking it were equivalent to
        evaluating the expression .resolve(java.net.URI)
        resolve`(URI.`.create(String) create`(str))`. 

        Arguments
        - str: The string to be parsed into a URI

        Returns
        - The resulting URI

        Raises
        - NullPointerException: If `str` is `null`
        - IllegalArgumentException: If the given string violates RFC&nbsp;2396
        """
        ...


    def relativize(self, uri: "URI") -> "URI":
        """
        Relativizes the given URI against this URI.
        
         The relativization of the given URI against this URI is computed as
        follows: 
        
        <ol>
        
          -  If either this URI or the given URI are opaque, or if the
          scheme and authority components of the two URIs are not identical, or
          if the path of this URI is not a prefix of the path of the given URI,
          then the given URI is returned. 
        
          -  Otherwise a new relative hierarchical URI is constructed with
          query and fragment components taken from the given URI and with a path
          component computed by removing this URI's path from the beginning of
          the given URI's path. 
        
        </ol>

        Arguments
        - uri: The URI to be relativized against this URI

        Returns
        - The resulting URI

        Raises
        - NullPointerException: If `uri` is `null`
        """
        ...


    def toURL(self) -> "URL":
        """
        Constructs a URL from this URI.
        
         This convenience method works as if invoking it were equivalent to
        evaluating the expression `new URL(this.toString())` after
        first checking that this URI is absolute. 

        Returns
        - A URL constructed from this URI

        Raises
        - IllegalArgumentException: If this URL is not absolute
        - MalformedURLException: If a protocol handler for the URL could not be found,
                 or if some other error occurred while constructing the URL
        """
        ...


    def getScheme(self) -> str:
        """
        Returns the scheme component of this URI.
        
         The scheme component of a URI, if defined, only contains characters
        in the *alphanum* category and in the string `"-.+"`.  A
        scheme always starts with an *alpha* character. 
        
        The scheme component of a URI cannot contain escaped octets, hence this
        method does not perform any decoding.

        Returns
        - The scheme component of this URI,
                 or `null` if the scheme is undefined
        """
        ...


    def isAbsolute(self) -> bool:
        """
        Tells whether or not this URI is absolute.
        
         A URI is absolute if, and only if, it has a scheme component. 

        Returns
        - `True` if, and only if, this URI is absolute
        """
        ...


    def isOpaque(self) -> bool:
        """
        Tells whether or not this URI is opaque.
        
         A URI is opaque if, and only if, it is absolute and its
        scheme-specific part does not begin with a slash character ('/').
        An opaque URI has a scheme, a scheme-specific part, and possibly
        a fragment; all other components are undefined. 

        Returns
        - `True` if, and only if, this URI is opaque
        """
        ...


    def getRawSchemeSpecificPart(self) -> str:
        """
        Returns the raw scheme-specific part of this URI.  The scheme-specific
        part is never undefined, though it may be empty.
        
         The scheme-specific part of a URI only contains legal URI
        characters. 

        Returns
        - The raw scheme-specific part of this URI
                 (never `null`)
        """
        ...


    def getSchemeSpecificPart(self) -> str:
        """
        Returns the decoded scheme-specific part of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawSchemeSpecificPart() getRawSchemeSpecificPart method
        except that all sequences of escaped octets are <a
        href="#decode">decoded</a>.  

        Returns
        - The decoded scheme-specific part of this URI
                 (never `null`)
        """
        ...


    def getRawAuthority(self) -> str:
        """
        Returns the raw authority component of this URI.
        
         The authority component of a URI, if defined, only contains the
        commercial-at character (`'@'`) and characters in the
        *unreserved*, *punct*, *escaped*, and *other*
        categories.  If the authority is server-based then it is further
        constrained to have valid user-information, host, and port
        components. 

        Returns
        - The raw authority component of this URI,
                 or `null` if the authority is undefined
        """
        ...


    def getAuthority(self) -> str:
        """
        Returns the decoded authority component of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawAuthority() getRawAuthority method except that all
        sequences of escaped octets are <a href="#decode">decoded</a>.  

        Returns
        - The decoded authority component of this URI,
                 or `null` if the authority is undefined
        """
        ...


    def getRawUserInfo(self) -> str:
        """
        Returns the raw user-information component of this URI.
        
         The user-information component of a URI, if defined, only contains
        characters in the *unreserved*, *punct*, *escaped*, and
        *other* categories. 

        Returns
        - The raw user-information component of this URI,
                 or `null` if the user information is undefined
        """
        ...


    def getUserInfo(self) -> str:
        """
        Returns the decoded user-information component of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawUserInfo() getRawUserInfo method except that all
        sequences of escaped octets are <a href="#decode">decoded</a>.  

        Returns
        - The decoded user-information component of this URI,
                 or `null` if the user information is undefined
        """
        ...


    def getHost(self) -> str:
        """
        Returns the host component of this URI.
        
         The host component of a URI, if defined, will have one of the
        following forms: 
        
        
        
          -  A domain name consisting of one or more *labels*
          separated by period characters (`'.'`), optionally followed by
          a period character.  Each label consists of *alphanum* characters
          as well as hyphen characters (`'-'`), though hyphens never
          occur as the first or last characters in a label. The rightmost
          label of a domain name consisting of two or more labels, begins
          with an *alpha* character. 
        
          -  A dotted-quad IPv4 address of the form
          *digit*`+.`*digit*`+.`*digit*`+.`*digit*`+`,
          where no *digit* sequence is longer than three characters and no
          sequence has a value larger than 255. 
        
          -  An IPv6 address enclosed in square brackets (`'['` and
          `']'`) and consisting of hexadecimal digits, colon characters
          (`':'`), and possibly an embedded IPv4 address.  The full
          syntax of IPv6 addresses is specified in <a
          href="http://www.ietf.org/rfc/rfc2373.txt">*RFC&nbsp;2373: IPv6
          Addressing Architecture*</a>.  
        
        
        
        The host component of a URI cannot contain escaped octets, hence this
        method does not perform any decoding.

        Returns
        - The host component of this URI,
                 or `null` if the host is undefined
        """
        ...


    def getPort(self) -> int:
        """
        Returns the port number of this URI.
        
         The port component of a URI, if defined, is a non-negative
        integer. 

        Returns
        - The port component of this URI,
                 or `-1` if the port is undefined
        """
        ...


    def getRawPath(self) -> str:
        """
        Returns the raw path component of this URI.
        
         The path component of a URI, if defined, only contains the slash
        character (`'/'`), the commercial-at character (`'@'`),
        and characters in the *unreserved*, *punct*, *escaped*,
        and *other* categories. 

        Returns
        - The path component of this URI,
                 or `null` if the path is undefined
        """
        ...


    def getPath(self) -> str:
        """
        Returns the decoded path component of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawPath() getRawPath method except that all sequences of
        escaped octets are <a href="#decode">decoded</a>.  

        Returns
        - The decoded path component of this URI,
                 or `null` if the path is undefined
        """
        ...


    def getRawQuery(self) -> str:
        """
        Returns the raw query component of this URI.
        
         The query component of a URI, if defined, only contains legal URI
        characters. 

        Returns
        - The raw query component of this URI,
                 or `null` if the query is undefined
        """
        ...


    def getQuery(self) -> str:
        """
        Returns the decoded query component of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawQuery() getRawQuery method except that all sequences of
        escaped octets are <a href="#decode">decoded</a>.  

        Returns
        - The decoded query component of this URI,
                 or `null` if the query is undefined
        """
        ...


    def getRawFragment(self) -> str:
        """
        Returns the raw fragment component of this URI.
        
         The fragment component of a URI, if defined, only contains legal URI
        characters. 

        Returns
        - The raw fragment component of this URI,
                 or `null` if the fragment is undefined
        """
        ...


    def getFragment(self) -> str:
        """
        Returns the decoded fragment component of this URI.
        
         The string returned by this method is equal to that returned by the
        .getRawFragment() getRawFragment method except that all
        sequences of escaped octets are <a href="#decode">decoded</a>.  

        Returns
        - The decoded fragment component of this URI,
                 or `null` if the fragment is undefined
        """
        ...


    def equals(self, ob: "Object") -> bool:
        """
        Tests this URI for equality with another object.
        
         If the given object is not a URI then this method immediately
        returns `False`.
        
         For two URIs to be considered equal requires that either both are
        opaque or both are hierarchical.  Their schemes must either both be
        undefined or else be equal without regard to case. Their fragments
        must either both be undefined or else be equal.
        
         For two opaque URIs to be considered equal, their scheme-specific
        parts must be equal.
        
         For two hierarchical URIs to be considered equal, their paths must
        be equal and their queries must either both be undefined or else be
        equal.  Their authorities must either both be undefined, or both be
        registry-based, or both be server-based.  If their authorities are
        defined and are registry-based, then they must be equal.  If their
        authorities are defined and are server-based, then their hosts must be
        equal without regard to case, their port numbers must be equal, and
        their user-information components must be equal.
        
         When testing the user-information, path, query, fragment, authority,
        or scheme-specific parts of two URIs for equality, the raw forms rather
        than the encoded forms of these components are compared and the
        hexadecimal digits of escaped octets are compared without regard to
        case.
        
         This method satisfies the general contract of the java.lang.Object.equals(Object) Object.equals method. 

        Arguments
        - ob: The object to which this object is to be compared

        Returns
        - `True` if, and only if, the given object is a URI that
                 is identical to this URI
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hash-code value for this URI.  The hash code is based upon all
        of the URI's components, and satisfies the general contract of the
        java.lang.Object.hashCode() Object.hashCode method.

        Returns
        - A hash-code value for this URI
        """
        ...


    def compareTo(self, that: "URI") -> int:
        """
        Compares this URI to another object, which must be a URI.
        
         When comparing corresponding components of two URIs, if one
        component is undefined but the other is defined then the first is
        considered to be less than the second.  Unless otherwise noted, string
        components are ordered according to their natural, case-sensitive
        ordering as defined by the java.lang.String.compareTo(String)
        String.compareTo method.  String components that are subject to
        encoding are compared by comparing their raw forms rather than their
        encoded forms and the hexadecimal digits of escaped octets are compared
        without regard to case.
        
         The ordering of URIs is defined as follows: 
        
        
        
          -  Two URIs with different schemes are ordered according the
          ordering of their schemes, without regard to case. 
        
          -  A hierarchical URI is considered to be less than an opaque URI
          with an identical scheme. 
        
          -  Two opaque URIs with identical schemes are ordered according
          to the ordering of their scheme-specific parts. 
        
          -  Two opaque URIs with identical schemes and scheme-specific
          parts are ordered according to the ordering of their
          fragments. 
        
          -  Two hierarchical URIs with identical schemes are ordered
          according to the ordering of their authority components: 
        
          
        
            -  If both authority components are server-based then the URIs
            are ordered according to their user-information components; if these
            components are identical then the URIs are ordered according to the
            ordering of their hosts, without regard to case; if the hosts are
            identical then the URIs are ordered according to the ordering of
            their ports. 
        
            -  If one or both authority components are registry-based then
            the URIs are ordered according to the ordering of their authority
            components. 
        
          
        
          -  Finally, two hierarchical URIs with identical schemes and
          authority components are ordered according to the ordering of their
          paths; if their paths are identical then they are ordered according to
          the ordering of their queries; if the queries are identical then they
          are ordered according to the order of their fragments. 
        
        
        
         This method satisfies the general contract of the java.lang.Comparable.compareTo(Object) Comparable.compareTo
        method. 

        Arguments
        - that: The object to which this URI is to be compared

        Returns
        - A negative integer, zero, or a positive integer as this URI is
                 less than, equal to, or greater than the given URI

        Raises
        - ClassCastException: If the given object is not a URI
        """
        ...


    def toString(self) -> str:
        """
        Returns the content of this URI as a string.
        
         If this URI was created by invoking one of the constructors in this
        class then a string equivalent to the original input string, or to the
        string computed from the originally-given components, as appropriate, is
        returned.  Otherwise this URI was created by normalization, resolution,
        or relativization, and so a string is constructed from this URI's
        components according to the rules specified in <a
        href="http://www.ietf.org/rfc/rfc2396.txt">RFC&nbsp;2396</a>,
        section&nbsp;5.2, step&nbsp;7. 

        Returns
        - The string form of this URI
        """
        ...


    def toASCIIString(self) -> str:
        """
        Returns the content of this URI as a US-ASCII string.
        
         If this URI does not contain any characters in the *other*
        category then an invocation of this method will return the same value as
        an invocation of the .toString() toString method.  Otherwise
        this method works as if by invoking that method and then <a
        href="#encode">encoding</a> the result.  

        Returns
        - The string form of this URI, encoded as needed
                 so that it only contains characters in the US-ASCII
                 charset
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.ConstructorConstructor

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import InstanceCreator
from com.google.gson import JsonIOException
from com.google.gson import ReflectionAccessFilter
from com.google.gson.ReflectionAccessFilter import FilterResult
from com.google.gson.internal import *
from com.google.gson.internal.reflect import ReflectionHelper
from com.google.gson.reflect import TypeToken
from java.lang.reflect import Constructor
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Modifier
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from java.util import ArrayDeque
from java.util import EnumMap
from java.util import EnumSet
from java.util import LinkedHashSet
from java.util import Queue
from java.util import SortedMap
from java.util import SortedSet
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import ConcurrentNavigableMap
from java.util.concurrent import ConcurrentSkipListMap
from typing import Any, Callable, Iterable, Tuple


class ConstructorConstructor:
    """
    Returns a function that can construct an instance of a requested type.
    """

    def __init__(self, instanceCreators: dict["Type", "InstanceCreator"[Any]], useJdkUnsafe: bool, reflectionFilters: list["ReflectionAccessFilter"]):
        ...


    def get(self, typeToken: "TypeToken"["T"]) -> "ObjectConstructor"["T"]:
        ...


    def toString(self) -> str:
        ...
